"""Constants for Agent Development Kit

Copyright PolyAI Limited
"""

PERMISSIONS = [
    "home",
    "conversations",
    "pii",
    "call_download",
    "intents",
    "entities",
    "metrics",
    "assistant_analysis",
    "custom_analytics",
    "safety_analytics",
    "about",
    "source_hub",
    "knowledge_base",
    "jupiter_flows",
    "functions",
    "as_api_integrations",
    "rules",
    "variant_management",
    "handoffs",
    "sms",
    "speech_recognition",
    "realtime_config_builder",
    "testing",
    "branch_management",
    "voice",
    "audio_cache",
    "response_control",
    "voice_channel",
    "webchat_channel",
    "environments",
    "settings",
    "numbers",
    "agent_config",
    "integrations",
    "custom_metrics",
    "realtime_config_manager",
    "webchat_configurations",
    "csat",
]
