# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from poly.handlers.protobuf import handoff_pb2 as handoff__pb2
from poly.handlers.protobuf import knowledge_base_pb2 as knowledge__base__pb2
from poly.handlers.protobuf import sms_pb2 as sms__pb2
from poly.handlers.protobuf import stop_keywords_pb2 as stop__keywords__pb2
from poly.handlers.protobuf import variant_pb2 as variant__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import languages_pb2 as languages__pb2
from poly.handlers.protobuf import transcript_corrections_pb2 as transcript__corrections__pb2
from poly.handlers.protobuf import flows_pb2 as flows__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2
from poly.handlers.protobuf import experimental_config_pb2 as experimental__config__pb2
from poly.handlers.protobuf import pronunciations_pb2 as pronunciations__pb2
from poly.handlers.protobuf import keyphrase_boosting_pb2 as keyphrase__boosting__pb2
from poly.handlers.protobuf import voice_pb2 as voice__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2
from poly.handlers.protobuf import start_function_pb2 as start__function__pb2
from poly.handlers.protobuf import end_function_pb2 as end__function__pb2
from poly.handlers.protobuf import entities_pb2 as entities__pb2
from poly.handlers.protobuf import api_integrations_pb2 as api__integrations__pb2
from poly.handlers.protobuf import variables_pb2 as variables__pb2
from poly.handlers.protobuf import translations_pb2 as translations__pb2
from poly.handlers.protobuf import channels_pb2 as channels__pb2
from poly.handlers.protobuf import csat_pb2 as csat__pb2
from poly.handlers.protobuf import integrations_pb2 as integrations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ommands.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\rhandoff.proto\x1a\x14knowledge_base.proto\x1a\tsms.proto\x1a\x13stop_keywords.proto\x1a\rvariant.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\x0flanguages.proto\x1a\x1ctranscript_corrections.proto\x1a\x0b\x66lows.proto\x1a\x14\x61gent_settings.proto\x1a\x19\x65xperimental_config.proto\x1a\x14pronunciations.proto\x1a\x18keyphrase_boosting.proto\x1a\x0bvoice.proto\x1a\x0f\x66unctions.proto\x1a\x14start_function.proto\x1a\x12\x65nd_function.proto\x1a\x0e\x65ntities.proto\x1a\x16\x61pi_integrations.proto\x1a\x0fvariables.proto\x1a\x12translations.proto\x1a\x0e\x63hannels.proto\x1a\ncsat.proto\x1a\x12integrations.proto\"N\n\x08Metadata\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\"\xa6N\n\x05\x45vent\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x12\n\ncommand_id\x18\x02 \x01(\t\x12\x34\n\x10server_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x08metadata\x18\xc8\x01 \x01(\x0b\x32\t.Metadata\x12\x41\n\x0c\x63reate_topic\x18\x04 \x01(\x0b\x32).knowledge_base.KnowledgeBase_CreateTopicH\x00\x12\x41\n\x0cupdate_topic\x18\x05 \x01(\x0b\x32).knowledge_base.KnowledgeBase_UpdateTopicH\x00\x12\x41\n\x0c\x64\x65lete_topic\x18\x06 \x01(\x0b\x32).knowledge_base.KnowledgeBase_DeleteTopicH\x00\x12\x43\n\rimport_topics\x18v \x01(\x0b\x32*.knowledge_base.KnowledgeBase_ImportTopicsH\x00\x12N\n\x13toggle_topic_status\x18w \x01(\x0b\x32/.knowledge_base.KnowledgeBase_ToggleTopicStatusH\x00\x12\x36\n\x13sms_create_template\x18\x07 \x01(\x0b\x32\x17.sms.SMS_CreateTemplateH\x00\x12\x36\n\x13sms_update_template\x18\x08 \x01(\x0b\x32\x17.sms.SMS_UpdateTemplateH\x00\x12\x36\n\x13sms_delete_template\x18\t \x01(\x0b\x32\x17.sms.SMS_DeleteTemplateH\x00\x12\x31\n\x0ehandoff_create\x18\n \x01(\x0b\x32\x17.handoff.Handoff_CreateH\x00\x12\x31\n\x0ehandoff_update\x18\x0b \x01(\x0b\x32\x17.handoff.Handoff_UpdateH\x00\x12\x31\n\x0ehandoff_delete\x18\x0c \x01(\x0b\x32\x17.handoff.Handoff_DeleteH\x00\x12:\n\x13handoff_set_default\x18. \x01(\x0b\x32\x1b.handoff.Handoff_SetDefaultH\x00\x12M\n\x1dhandoff_reset_handoff_configs\x18H \x01(\x0b\x32$.handoff.Handoff_ResetHandoffConfigsH\x00\x12\x32\n\x10\x63reate_flow_step\x18\x64 \x01(\x0b\x32\x16.flows.Flow_CreateStepH\x00\x12\x32\n\x10update_flow_step\x18\x65 \x01(\x0b\x32\x16.flows.Flow_UpdateStepH\x00\x12\x32\n\x10\x64\x65lete_flow_step\x18\x66 \x01(\x0b\x32\x16.flows.Flow_DeleteStepH\x00\x12\x43\n\x19update_flow_step_position\x18g \x01(\x0b\x32\x1e.flows.Flow_UpdateStepPositionH\x00\x12\x45\n\x1aupdate_flow_step_positions\x18h \x01(\x0b\x32\x1f.flows.Flow_UpdateStepPositionsH\x00\x12H\n\x1cupdate_flow_step_dtmf_config\x18i \x01(\x0b\x32 .flows.Flow_UpdateStepDtmfConfigH\x00\x12\x46\n\x1bupdate_flow_step_asr_config\x18j \x01(\x0b\x32\x1f.flows.Flow_UpdateStepAsrConfigH\x00\x12O\n\x1f\x63reate_flow_transition_function\x18k \x01(\x0b\x32$.flows.Flow_CreateTransitionFunctionH\x00\x12O\n\x1fupdate_flow_transition_function\x18l \x01(\x0b\x32$.flows.Flow_UpdateTransitionFunctionH\x00\x12O\n\x1f\x64\x65lete_flow_transition_function\x18m \x01(\x0b\x32$.flows.Flow_DeleteTransitionFunctionH\x00\x12-\n\x0b\x64\x65lete_flow\x18n \x01(\x0b\x32\x16.flows.Flow_DeleteFlowH\x00\x12-\n\x0b\x63reate_flow\x18o \x01(\x0b\x32\x16.flows.Flow_CreateFlowH\x00\x12-\n\x0bimport_flow\x18p \x01(\x0b\x32\x16.flows.Flow_ImportFlowH\x00\x12-\n\x0bupdate_flow\x18q \x01(\x0b\x32\x16.flows.Flow_UpdateFlowH\x00\x12m\n/update_flow_transition_function_latency_control\x18r \x01(\x0b\x32\x32.flows.Flow_UpdateTransitionFunctionLatencyControlH\x00\x12\x37\n\x13\x63reate_no_code_step\x18\xd6\x01 \x01(\x0b\x32\x17.flows.CreateNoCodeStepH\x00\x12\x37\n\x13update_no_code_step\x18\xd7\x01 \x01(\x0b\x32\x17.flows.UpdateNoCodeStepH\x00\x12\x37\n\x13\x64\x65lete_no_code_step\x18\xd8\x01 \x01(\x0b\x32\x17.flows.DeleteNoCodeStepH\x00\x12H\n\x1cupdate_no_code_step_position\x18\xd9\x01 \x01(\x0b\x32\x1f.flows.UpdateNoCodeStepPositionH\x00\x12\x41\n\x18\x63reate_no_code_condition\x18\xda\x01 \x01(\x0b\x32\x1c.flows.CreateNoCodeConditionH\x00\x12\x41\n\x18\x64\x65lete_no_code_condition\x18\xdb\x01 \x01(\x0b\x32\x1c.flows.DeleteNoCodeConditionH\x00\x12\x41\n\x18update_no_code_condition\x18\xdc\x01 \x01(\x0b\x32\x1c.flows.UpdateNoCodeConditionH\x00\x12R\n!update_no_code_condition_position\x18\xdd\x01 \x01(\x0b\x32$.flows.UpdateNoCodeConditionPositionH\x00\x12\x64\n+update_no_code_condition_exit_flow_position\x18\xde\x01 \x01(\x0b\x32,.flows.UpdateNoCodeConditionExitFlowPositionH\x00\x12\x38\n\x13move_flow_component\x18\xdf\x01 \x01(\x0b\x32\x18.flows.MoveFlowComponentH\x00\x12:\n\x14move_flow_components\x18\xe0\x01 \x01(\x0b\x32\x19.flows.MoveFlowComponentsH\x00\x12)\n\x0b\x63reate_step\x18\xb3\x02 \x01(\x0b\x32\x11.flows.CreateStepH\x00\x12)\n\x0bupdate_step\x18\xb4\x02 \x01(\x0b\x32\x11.flows.UpdateStepH\x00\x12)\n\x0b\x64\x65lete_step\x18\xb5\x02 \x01(\x0b\x32\x11.flows.DeleteStepH\x00\x12<\n\x15\x63reate_step_condition\x18\xb6\x02 \x01(\x0b\x32\x1a.flows.CreateStepConditionH\x00\x12<\n\x15update_step_condition\x18\xb7\x02 \x01(\x0b\x32\x1a.flows.UpdateStepConditionH\x00\x12<\n\x15\x64\x65lete_step_condition\x18\xb8\x02 \x01(\x0b\x32\x1a.flows.DeleteStepConditionH\x00\x12M\n\x1eupdate_step_condition_position\x18\xb9\x02 \x01(\x0b\x32\".flows.UpdateStepConditionPositionH\x00\x12\x44\n\x18variant_create_attribute\x18\x12 \x01(\x0b\x32 .variant.Variant_CreateAttributeH\x00\x12\x44\n\x18variant_update_attribute\x18\x13 \x01(\x0b\x32 .variant.Variant_UpdateAttributeH\x00\x12\x44\n\x18variant_delete_attribute\x18\x14 \x01(\x0b\x32 .variant.Variant_DeleteAttributeH\x00\x12@\n\x16variant_create_variant\x18\x15 \x01(\x0b\x32\x1e.variant.Variant_CreateVariantH\x00\x12@\n\x16variant_update_variant\x18\x16 \x01(\x0b\x32\x1e.variant.Variant_UpdateVariantH\x00\x12@\n\x16variant_delete_variant\x18\x17 \x01(\x0b\x32\x1e.variant.Variant_DeleteVariantH\x00\x12I\n\x1bvariant_set_default_variant\x18\x18 \x01(\x0b\x32\".variant.Variant_SetDefaultVariantH\x00\x12\x42\n\x17variant_import_variants\x18\x32 \x01(\x0b\x32\x1f.variant.Variant_ImportVariantsH\x00\x12\x41\n\x14stop_keywords_create\x18\x19 \x01(\x0b\x32!.stop_keywords.StopKeyword_CreateH\x00\x12\x41\n\x14stop_keywords_update\x18\x1a \x01(\x0b\x32!.stop_keywords.StopKeyword_UpdateH\x00\x12\x41\n\x14stop_keywords_delete\x18\x1b \x01(\x0b\x32!.stop_keywords.StopKeyword_DeleteH\x00\x12J\n\x13update_llm_settings\x18\x1c \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettingsH\x00\x12t\n\x1eupdate_content_filter_settings\x18\x1d \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettingsH\x00\x12J\n\x13update_asr_settings\x18\x1e \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettingsH\x00\x12M\n\x13update_tts_settings\x18\x1f \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageB\x02\x18\x01H\x00\x12X\n!languages_update_default_language\x18\xe4\x01 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageH\x00\x12\x43\n\x16languages_add_language\x18\xe5\x01 \x01(\x0b\x32 .languages.Languages_AddLanguageH\x00\x12I\n\x19languages_delete_language\x18\xe6\x01 \x01(\x0b\x32#.languages.Languages_DeleteLanguageH\x00\x12\x61\n!experimental_config_update_config\x18  \x01(\x0b\x32\x34.experimental_config.ExperimentalConfig_UpdateConfigH\x00\x12\x61\n#pronunciations_create_pronunciation\x18! \x01(\x0b\x32\x32.pronunciations.Pronunciations_CreatePronunciationH\x00\x12\x61\n#pronunciations_update_pronunciation\x18\" \x01(\x0b\x32\x32.pronunciations.Pronunciations_UpdatePronunciationH\x00\x12\x61\n#pronunciations_delete_pronunciation\x18# \x01(\x0b\x32\x32.pronunciations.Pronunciations_DeletePronunciationH\x00\x12\x66\n%pronunciations_reorder_pronunciations\x18\xed\x02 \x01(\x0b\x32\x34.pronunciations.Pronunciations_ReorderPronunciationsH\x00\x12r\n\x1d\x63reate_transcript_corrections\x18% \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_CreateTranscriptCorrectionsH\x00\x12r\n\x1dupdate_transcript_corrections\x18& \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_UpdateTranscriptCorrectionsH\x00\x12r\n\x1d\x64\x65lete_transcript_corrections\x18\' \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_DeleteTranscriptCorrectionsH\x00\x12\x39\n\x0fupdate_greeting\x18( \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreetingH\x00\x12\x42\n\x12update_personality\x18) \x01(\x0b\x32$.agent.Personality_UpdatePersonalityH\x00\x12-\n\x0bupdate_role\x18* \x01(\x0b\x32\x16.agent.Role_UpdateRoleH\x00\x12U\n\x19update_disclaimer_message\x18+ \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessageH\x00\x12\x30\n\x0cupdate_rules\x18, \x01(\x0b\x32\x18.agent.Rules_UpdateRulesH\x00\x12R\n\x18update_language_behavior\x18G \x01(\x0b\x32..agent.LanguageBehavior_UpdateLanguageBehaviorH\x00\x12=\n\x0f\x63reate_function\x18- \x01(\x0b\x32\".functions.Function_CreateFunctionH\x00\x12=\n\x0fupdate_function\x18\x30 \x01(\x0b\x32\".functions.Function_UpdateFunctionH\x00\x12=\n\x0f\x64\x65lete_function\x18\x31 \x01(\x0b\x32\".functions.Function_DeleteFunctionH\x00\x12J\n\x16update_latency_control\x18; \x01(\x0b\x32(.functions.Function_UpdateLatencyControlH\x00\x12\x45\n\x15\x63reate_start_function\x18< \x01(\x0b\x32$.start_function.StartFunction_CreateH\x00\x12\x45\n\x15update_start_function\x18= \x01(\x0b\x32$.start_function.StartFunction_UpdateH\x00\x12\x45\n\x15\x64\x65lete_start_function\x18\x41 \x01(\x0b\x32$.start_function.StartFunction_DeleteH\x00\x12?\n\x13\x63reate_end_function\x18> \x01(\x0b\x32 .end_function.EndFunction_CreateH\x00\x12?\n\x13update_end_function\x18? \x01(\x0b\x32 .end_function.EndFunction_UpdateH\x00\x12?\n\x13\x64\x65lete_end_function\x18\x42 \x01(\x0b\x32 .end_function.EndFunction_DeleteH\x00\x12Z\n\x19\x63reate_keyphrase_boosting\x18s \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_CreateKeyphraseH\x00\x12Z\n\x19update_keyphrase_boosting\x18t \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_UpdateKeyphraseH\x00\x12Z\n\x19\x64\x65lete_keyphrase_boosting\x18u \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_DeleteKeyphraseH\x00\x12;\n\x15voice_add_agent_voice\x18\x33 \x01(\x0b\x32\x1a.voice.Voice_AddAgentVoiceH\x00\x12\x41\n\x18voice_delete_agent_voice\x18\x34 \x01(\x0b\x32\x1d.voice.Voice_DeleteAgentVoiceH\x00\x12\x41\n\x18voice_update_agent_voice\x18\x35 \x01(\x0b\x32\x1d.voice.Voice_UpdateAgentVoiceH\x00\x12R\n!voice_create_agent_voice_settings\x18\x36 \x01(\x0b\x32%.voice.Voice_CreateAgentVoiceSettingsH\x00\x12R\n!voice_update_agent_voice_settings\x18\x37 \x01(\x0b\x32%.voice.Voice_UpdateAgentVoiceSettingsH\x00\x12K\n\x1dvoice_update_disclaimer_voice\x18\x38 \x01(\x0b\x32\".voice.Voice_UpdateDisclaimerVoiceH\x00\x12\\\n&voice_create_disclaimer_voice_settings\x18\x39 \x01(\x0b\x32*.voice.Voice_CreateDisclaimerVoiceSettingsH\x00\x12\\\n&voice_update_disclaimer_voice_settings\x18: \x01(\x0b\x32*.voice.Voice_UpdateDisclaimerVoiceSettingsH\x00\x12\x41\n\x18voice_add_favorite_voice\x18x \x01(\x0b\x32\x1d.voice.Voice_AddFavoriteVoiceH\x00\x12G\n\x1bvoice_remove_favorite_voice\x18y \x01(\x0b\x32 .voice.Voice_RemoveFavoriteVoiceH\x00\x12\x34\n\x14\x62ranch_trigger_merge\x18\r \x01(\x0b\x32\x14.Branch_TriggerMergeH\x00\x12)\n\x0e\x62ranch_created\x18\x0e \x01(\x0b\x32\x0f.Branch_CreatedH\x00\x12\'\n\rbranch_merged\x18\x0f \x01(\x0b\x32\x0e.Branch_MergedH\x00\x12)\n\x0e\x62ranch_deleted\x18/ \x01(\x0b\x32\x0f.Branch_DeletedH\x00\x12+\n\x0fproject_created\x18\x10 \x01(\x0b\x32\x10.Project_CreatedH\x00\x12\x41\n\x1bproject_loaded_from_jupiter\x18\x11 \x01(\x0b\x32\x1a.Project_LoadedFromJupiterH\x00\x12\x34\n\x14\x64\x65ployment_completed\x18$ \x01(\x0b\x32\x14.DeploymentCompletedH\x00\x12\x32\n\x13\x64\x65ployment_rollback\x18@ \x01(\x0b\x32\x13.DeploymentRollbackH\x00\x12\x30\n\rentity_create\x18\x43 \x01(\x0b\x32\x17.entities.Entity_CreateH\x00\x12\x30\n\rentity_update\x18\x44 \x01(\x0b\x32\x17.entities.Entity_UpdateH\x00\x12\x30\n\rentity_delete\x18\x45 \x01(\x0b\x32\x17.entities.Entity_DeleteH\x00\x12\x36\n\x0fvariable_create\x18\xe1\x01 \x01(\x0b\x32\x1a.variables.Variable_CreateH\x00\x12\x36\n\x0fvariable_update\x18\xe2\x01 \x01(\x0b\x32\x1a.variables.Variable_UpdateH\x00\x12\x36\n\x0fvariable_delete\x18\xe3\x01 \x01(\x0b\x32\x1a.variables.Variable_DeleteH\x00\x12\x45\n\x1d\x66unction_deployment_completed\x18\x46 \x01(\x0b\x32\x1c.FunctionDeploymentCompletedH\x00\x12J\n\x16\x63reate_api_integration\x18\xac\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_CreateH\x00\x12J\n\x16update_api_integration\x18\xad\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_UpdateH\x00\x12J\n\x16\x64\x65lete_api_integration\x18\xae\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_DeleteH\x00\x12W\n\x1dupdate_api_integration_config\x18\xaf\x02 \x01(\x0b\x32-.api_integrations.ApiIntegrationConfig_UpdateH\x00\x12]\n create_api_integration_operation\x18\xb0\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_CreateH\x00\x12]\n update_api_integration_operation\x18\xb1\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_UpdateH\x00\x12]\n delete_api_integration_operation\x18\xb2\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_DeleteH\x00\x12K\n\x12\x63reate_translation\x18\xdf\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_CreateH\x00\x12K\n\x12update_translation\x18\xe0\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_UpdateH\x00\x12K\n\x12\x64\x65lete_translation\x18\xe1\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_DeleteH\x00\x12V\n!voice_channel_update_asr_settings\x18\xe6\x02 \x01(\x0b\x32(.channels.VoiceChannel_UpdateASRSettingsH\x00\x12S\n\x1fvoice_channel_update_disclaimer\x18\xe7\x02 \x01(\x0b\x32\'.channels.VoiceChannel_UpdateDisclaimerH\x00\x12\x44\n\x17\x63hannel_update_greeting\x18\xf8\x02 \x01(\x0b\x32 .channels.Channel_UpdateGreetingH\x00\x12K\n\x1b\x63hannel_update_style_prompt\x18\xf9\x02 \x01(\x0b\x32#.channels.Channel_UpdateStylePromptH\x00\x12O\n\x1d\x63hannel_update_safety_filters\x18\xfa\x02 \x01(\x0b\x32%.channels.Channel_UpdateSafetyFiltersH\x00\x12K\n\x1b\x63hannel_update_llm_settings\x18\xfb\x02 \x01(\x0b\x32#.channels.Channel_UpdateLLMSettingsH\x00\x12@\n\x15\x63hannel_update_status\x18\xfc\x02 \x01(\x0b\x32\x1e.channels.Channel_UpdateStatusH\x00\x12\x36\n\x12\x63sat_update_config\x18\xf2\x02 \x01(\x0b\x32\x17.csat.CSAT_UpdateConfigH\x00\x12\x41\n\x13\x63onnect_integration\x18\xf3\x02 \x01(\x0b\x32!.integrations.Integration_ConnectH\x00\x12?\n\x12\x65nable_integration\x18\xf4\x02 \x01(\x0b\x32 .integrations.Integration_EnableH\x00\x12\x41\n\x13\x64isable_integration\x18\xf7\x02 \x01(\x0b\x32!.integrations.Integration_DisableH\x00\x12R\n\x1cupdate_integration_functions\x18\xf5\x02 \x01(\x0b\x32).integrations.Integration_UpdateFunctionsH\x00\x12G\n\x16\x64isconnect_integration\x18\xf6\x02 \x01(\x0b\x32$.integrations.Integration_DisconnectH\x00\x42\t\n\x07payloadJ\x06\x08\xe2\x02\x10\xe3\x02J\x06\x08\xe3\x02\x10\xe4\x02J\x06\x08\xe4\x02\x10\xe5\x02J\x06\x08\xe5\x02\x10\xe6\x02J\x06\x08\xe8\x02\x10\xe9\x02J\x06\x08\xe9\x02\x10\xea\x02J\x06\x08\xea\x02\x10\xeb\x02J\x06\x08\xeb\x02\x10\xec\x02J\x06\x08\xec\x02\x10\xed\x02\"$\n\nEventBatch\x12\x16\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x06.Event\"k\n\rSetProjection\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x12\n\nprojection\x18\x02 \x01(\x0c\x12\x34\n\x10server_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1e\n\x0bSocketError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xa9\x01\n\x08\x45nvelope\x12\"\n\x0b\x65vent_batch\x18\x01 \x01(\x0b\x32\x0b.EventBatchH\x00\x12(\n\x0eset_projection\x18\x02 \x01(\x0b\x32\x0e.SetProjectionH\x00\x12%\n\x0cnotification\x18\x03 \x01(\x0b\x32\r.NotificationH\x00\x12\x1d\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x0c.SocketErrorH\x00\x42\t\n\x07message\"\xdc\x01\n\x0cNotification\x12\x0c\n\x04type\x18\x01 \x01(\t\x12)\n\x0e\x62ranch_created\x18\x02 \x01(\x0b\x32\x0f.Branch_CreatedH\x00\x12\'\n\rbranch_merged\x18\x03 \x01(\x0b\x32\x0e.Branch_MergedH\x00\x12)\n\x0e\x62ranch_deleted\x18\x04 \x01(\x0b\x32\x0f.Branch_DeletedH\x00\x12\x34\n\x14\x62ranch_trigger_merge\x18\x05 \x01(\x0b\x32\x14.Branch_TriggerMergeH\x00\x42\t\n\x07payload\"\x9aJ\n\x07\x43ommand\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1c\n\x08metadata\x18\xc8\x01 \x01(\x0b\x32\t.Metadata\x12\x12\n\ncommand_id\x18\x02 \x01(\t\x12\x41\n\x0c\x63reate_topic\x18\x03 \x01(\x0b\x32).knowledge_base.KnowledgeBase_CreateTopicH\x00\x12\x41\n\x0cupdate_topic\x18\x04 \x01(\x0b\x32).knowledge_base.KnowledgeBase_UpdateTopicH\x00\x12\x41\n\x0c\x64\x65lete_topic\x18\x05 \x01(\x0b\x32).knowledge_base.KnowledgeBase_DeleteTopicH\x00\x12\x43\n\rimport_topics\x18v \x01(\x0b\x32*.knowledge_base.KnowledgeBase_ImportTopicsH\x00\x12N\n\x13toggle_topic_status\x18w \x01(\x0b\x32/.knowledge_base.KnowledgeBase_ToggleTopicStatusH\x00\x12\x36\n\x13sms_create_template\x18\x06 \x01(\x0b\x32\x17.sms.SMS_CreateTemplateH\x00\x12\x36\n\x13sms_update_template\x18\x07 \x01(\x0b\x32\x17.sms.SMS_UpdateTemplateH\x00\x12\x36\n\x13sms_delete_template\x18\x08 \x01(\x0b\x32\x17.sms.SMS_DeleteTemplateH\x00\x12\x31\n\x0ehandoff_create\x18\t \x01(\x0b\x32\x17.handoff.Handoff_CreateH\x00\x12\x31\n\x0ehandoff_update\x18\n \x01(\x0b\x32\x17.handoff.Handoff_UpdateH\x00\x12\x31\n\x0ehandoff_delete\x18\x0b \x01(\x0b\x32\x17.handoff.Handoff_DeleteH\x00\x12:\n\x13handoff_set_default\x18\x1a \x01(\x0b\x32\x1b.handoff.Handoff_SetDefaultH\x00\x12M\n\x1dhandoff_reset_handoff_configs\x18/ \x01(\x0b\x32$.handoff.Handoff_ResetHandoffConfigsH\x00\x12\x44\n\x18variant_create_attribute\x18\x0c \x01(\x0b\x32 .variant.Variant_CreateAttributeH\x00\x12\x44\n\x18variant_update_attribute\x18\r \x01(\x0b\x32 .variant.Variant_UpdateAttributeH\x00\x12\x44\n\x18variant_delete_attribute\x18\x0e \x01(\x0b\x32 .variant.Variant_DeleteAttributeH\x00\x12@\n\x16variant_create_variant\x18\x0f \x01(\x0b\x32\x1e.variant.Variant_CreateVariantH\x00\x12@\n\x16variant_update_variant\x18\x10 \x01(\x0b\x32\x1e.variant.Variant_UpdateVariantH\x00\x12@\n\x16variant_delete_variant\x18\x11 \x01(\x0b\x32\x1e.variant.Variant_DeleteVariantH\x00\x12I\n\x1bvariant_set_default_variant\x18\x12 \x01(\x0b\x32\".variant.Variant_SetDefaultVariantH\x00\x12\x42\n\x17variant_import_variants\x18\x32 \x01(\x0b\x32\x1f.variant.Variant_ImportVariantsH\x00\x12\x41\n\x14stop_keywords_create\x18\x13 \x01(\x0b\x32!.stop_keywords.StopKeyword_CreateH\x00\x12\x41\n\x14stop_keywords_update\x18\x14 \x01(\x0b\x32!.stop_keywords.StopKeyword_UpdateH\x00\x12\x41\n\x14stop_keywords_delete\x18\x15 \x01(\x0b\x32!.stop_keywords.StopKeyword_DeleteH\x00\x12J\n\x13update_llm_settings\x18\x16 \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettingsH\x00\x12t\n\x1eupdate_content_filter_settings\x18\x17 \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettingsH\x00\x12J\n\x13update_asr_settings\x18\x18 \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettingsH\x00\x12M\n\x13update_tts_settings\x18\x19 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageB\x02\x18\x01H\x00\x12X\n!languages_update_default_language\x18\xe7\x01 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageH\x00\x12\x43\n\x16languages_add_language\x18\xe8\x01 \x01(\x0b\x32 .languages.Languages_AddLanguageH\x00\x12I\n\x19languages_delete_language\x18\xe9\x01 \x01(\x0b\x32#.languages.Languages_DeleteLanguageH\x00\x12\x61\n!experimental_config_update_config\x18\' \x01(\x0b\x32\x34.experimental_config.ExperimentalConfig_UpdateConfigH\x00\x12\x61\n#pronunciations_create_pronunciation\x18\x1b \x01(\x0b\x32\x32.pronunciations.Pronunciations_CreatePronunciationH\x00\x12\x61\n#pronunciations_update_pronunciation\x18\x1c \x01(\x0b\x32\x32.pronunciations.Pronunciations_UpdatePronunciationH\x00\x12\x61\n#pronunciations_delete_pronunciation\x18\x1d \x01(\x0b\x32\x32.pronunciations.Pronunciations_DeletePronunciationH\x00\x12\x65\n%pronunciations_reorder_pronunciations\x18< \x01(\x0b\x32\x34.pronunciations.Pronunciations_ReorderPronunciationsH\x00\x12r\n\x1d\x63reate_transcript_corrections\x18\x1e \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_CreateTranscriptCorrectionsH\x00\x12r\n\x1dupdate_transcript_corrections\x18\x1f \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_UpdateTranscriptCorrectionsH\x00\x12r\n\x1d\x64\x65lete_transcript_corrections\x18  \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_DeleteTranscriptCorrectionsH\x00\x12\x39\n\x0fupdate_greeting\x18! \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreetingH\x00\x12\x42\n\x12update_personality\x18\" \x01(\x0b\x32$.agent.Personality_UpdatePersonalityH\x00\x12-\n\x0bupdate_role\x18# \x01(\x0b\x32\x16.agent.Role_UpdateRoleH\x00\x12U\n\x19update_disclaimer_message\x18$ \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessageH\x00\x12\x30\n\x0cupdate_rules\x18% \x01(\x0b\x32\x18.agent.Rules_UpdateRulesH\x00\x12R\n\x18update_language_behavior\x18; \x01(\x0b\x32..agent.LanguageBehavior_UpdateLanguageBehaviorH\x00\x12=\n\x0f\x63reate_function\x18& \x01(\x0b\x32\".functions.Function_CreateFunctionH\x00\x12=\n\x0fupdate_function\x18( \x01(\x0b\x32\".functions.Function_UpdateFunctionH\x00\x12=\n\x0f\x64\x65lete_function\x18) \x01(\x0b\x32\".functions.Function_DeleteFunctionH\x00\x12J\n\x16update_latency_control\x18* \x01(\x0b\x32(.functions.Function_UpdateLatencyControlH\x00\x12\x45\n\x15\x63reate_start_function\x18+ \x01(\x0b\x32$.start_function.StartFunction_CreateH\x00\x12\x45\n\x15update_start_function\x18, \x01(\x0b\x32$.start_function.StartFunction_UpdateH\x00\x12\x45\n\x15\x64\x65lete_start_function\x18\x30 \x01(\x0b\x32$.start_function.StartFunction_DeleteH\x00\x12?\n\x13\x63reate_end_function\x18- \x01(\x0b\x32 .end_function.EndFunction_CreateH\x00\x12?\n\x13update_end_function\x18. \x01(\x0b\x32 .end_function.EndFunction_UpdateH\x00\x12?\n\x13\x64\x65lete_end_function\x18\x31 \x01(\x0b\x32 .end_function.EndFunction_DeleteH\x00\x12;\n\x15voice_add_agent_voice\x18\x33 \x01(\x0b\x32\x1a.voice.Voice_AddAgentVoiceH\x00\x12\x41\n\x18voice_delete_agent_voice\x18\x34 \x01(\x0b\x32\x1d.voice.Voice_DeleteAgentVoiceH\x00\x12\x41\n\x18voice_update_agent_voice\x18\x35 \x01(\x0b\x32\x1d.voice.Voice_UpdateAgentVoiceH\x00\x12R\n!voice_create_agent_voice_settings\x18\x36 \x01(\x0b\x32%.voice.Voice_CreateAgentVoiceSettingsH\x00\x12R\n!voice_update_agent_voice_settings\x18\x37 \x01(\x0b\x32%.voice.Voice_UpdateAgentVoiceSettingsH\x00\x12K\n\x1dvoice_update_disclaimer_voice\x18\x38 \x01(\x0b\x32\".voice.Voice_UpdateDisclaimerVoiceH\x00\x12\\\n&voice_create_disclaimer_voice_settings\x18\x39 \x01(\x0b\x32*.voice.Voice_CreateDisclaimerVoiceSettingsH\x00\x12\\\n&voice_update_disclaimer_voice_settings\x18: \x01(\x0b\x32*.voice.Voice_UpdateDisclaimerVoiceSettingsH\x00\x12\x41\n\x18voice_add_favorite_voice\x18x \x01(\x0b\x32\x1d.voice.Voice_AddFavoriteVoiceH\x00\x12G\n\x1bvoice_remove_favorite_voice\x18y \x01(\x0b\x32 .voice.Voice_RemoveFavoriteVoiceH\x00\x12\x31\n\rentity_create\x18\xa5\x01 \x01(\x0b\x32\x17.entities.Entity_CreateH\x00\x12\x31\n\rentity_update\x18\xa6\x01 \x01(\x0b\x32\x17.entities.Entity_UpdateH\x00\x12\x31\n\rentity_delete\x18\xa7\x01 \x01(\x0b\x32\x17.entities.Entity_DeleteH\x00\x12\x36\n\x0fvariable_create\x18\xa8\x01 \x01(\x0b\x32\x1a.variables.Variable_CreateH\x00\x12\x36\n\x0fvariable_update\x18\xa9\x01 \x01(\x0b\x32\x1a.variables.Variable_UpdateH\x00\x12\x36\n\x0fvariable_delete\x18\xaa\x01 \x01(\x0b\x32\x1a.variables.Variable_DeleteH\x00\x12\x32\n\x10\x63reate_flow_step\x18\x64 \x01(\x0b\x32\x16.flows.Flow_CreateStepH\x00\x12\x32\n\x10update_flow_step\x18\x65 \x01(\x0b\x32\x16.flows.Flow_UpdateStepH\x00\x12\x32\n\x10\x64\x65lete_flow_step\x18\x66 \x01(\x0b\x32\x16.flows.Flow_DeleteStepH\x00\x12\x43\n\x19update_flow_step_position\x18g \x01(\x0b\x32\x1e.flows.Flow_UpdateStepPositionH\x00\x12\x45\n\x1aupdate_flow_step_positions\x18h \x01(\x0b\x32\x1f.flows.Flow_UpdateStepPositionsH\x00\x12H\n\x1cupdate_flow_step_dtmf_config\x18i \x01(\x0b\x32 .flows.Flow_UpdateStepDtmfConfigH\x00\x12\x46\n\x1bupdate_flow_step_asr_config\x18j \x01(\x0b\x32\x1f.flows.Flow_UpdateStepAsrConfigH\x00\x12O\n\x1f\x63reate_flow_transition_function\x18k \x01(\x0b\x32$.flows.Flow_CreateTransitionFunctionH\x00\x12O\n\x1fupdate_flow_transition_function\x18l \x01(\x0b\x32$.flows.Flow_UpdateTransitionFunctionH\x00\x12O\n\x1f\x64\x65lete_flow_transition_function\x18m \x01(\x0b\x32$.flows.Flow_DeleteTransitionFunctionH\x00\x12-\n\x0b\x64\x65lete_flow\x18n \x01(\x0b\x32\x16.flows.Flow_DeleteFlowH\x00\x12-\n\x0b\x63reate_flow\x18o \x01(\x0b\x32\x16.flows.Flow_CreateFlowH\x00\x12-\n\x0bimport_flow\x18p \x01(\x0b\x32\x16.flows.Flow_ImportFlowH\x00\x12-\n\x0bupdate_flow\x18q \x01(\x0b\x32\x16.flows.Flow_UpdateFlowH\x00\x12m\n/update_flow_transition_function_latency_control\x18r \x01(\x0b\x32\x32.flows.Flow_UpdateTransitionFunctionLatencyControlH\x00\x12\x37\n\x13\x63reate_no_code_step\x18\xd6\x01 \x01(\x0b\x32\x17.flows.CreateNoCodeStepH\x00\x12\x37\n\x13update_no_code_step\x18\xd7\x01 \x01(\x0b\x32\x17.flows.UpdateNoCodeStepH\x00\x12\x37\n\x13\x64\x65lete_no_code_step\x18\xd8\x01 \x01(\x0b\x32\x17.flows.DeleteNoCodeStepH\x00\x12H\n\x1cupdate_no_code_step_position\x18\xd9\x01 \x01(\x0b\x32\x1f.flows.UpdateNoCodeStepPositionH\x00\x12\x41\n\x18\x63reate_no_code_condition\x18\xda\x01 \x01(\x0b\x32\x1c.flows.CreateNoCodeConditionH\x00\x12\x41\n\x18\x64\x65lete_no_code_condition\x18\xdb\x01 \x01(\x0b\x32\x1c.flows.DeleteNoCodeConditionH\x00\x12\x41\n\x18update_no_code_condition\x18\xdc\x01 \x01(\x0b\x32\x1c.flows.UpdateNoCodeConditionH\x00\x12R\n!update_no_code_condition_position\x18\xdd\x01 \x01(\x0b\x32$.flows.UpdateNoCodeConditionPositionH\x00\x12\x64\n+update_no_code_condition_exit_flow_position\x18\xde\x01 \x01(\x0b\x32,.flows.UpdateNoCodeConditionExitFlowPositionH\x00\x12\x38\n\x13move_flow_component\x18\xdf\x01 \x01(\x0b\x32\x18.flows.MoveFlowComponentH\x00\x12:\n\x14move_flow_components\x18\xe0\x01 \x01(\x0b\x32\x19.flows.MoveFlowComponentsH\x00\x12)\n\x0b\x63reate_step\x18\xb3\x02 \x01(\x0b\x32\x11.flows.CreateStepH\x00\x12)\n\x0bupdate_step\x18\xb4\x02 \x01(\x0b\x32\x11.flows.UpdateStepH\x00\x12)\n\x0b\x64\x65lete_step\x18\xb5\x02 \x01(\x0b\x32\x11.flows.DeleteStepH\x00\x12<\n\x15\x63reate_step_condition\x18\xb6\x02 \x01(\x0b\x32\x1a.flows.CreateStepConditionH\x00\x12<\n\x15update_step_condition\x18\xb7\x02 \x01(\x0b\x32\x1a.flows.UpdateStepConditionH\x00\x12<\n\x15\x64\x65lete_step_condition\x18\xb8\x02 \x01(\x0b\x32\x1a.flows.DeleteStepConditionH\x00\x12M\n\x1eupdate_step_condition_position\x18\xb9\x02 \x01(\x0b\x32\".flows.UpdateStepConditionPositionH\x00\x12Z\n\x19\x63reate_keyphrase_boosting\x18s \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_CreateKeyphraseH\x00\x12Z\n\x19update_keyphrase_boosting\x18t \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_UpdateKeyphraseH\x00\x12Z\n\x19\x64\x65lete_keyphrase_boosting\x18u \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_DeleteKeyphraseH\x00\x12J\n\x16\x63reate_api_integration\x18\xac\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_CreateH\x00\x12J\n\x16update_api_integration\x18\xad\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_UpdateH\x00\x12J\n\x16\x64\x65lete_api_integration\x18\xae\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_DeleteH\x00\x12W\n\x1dupdate_api_integration_config\x18\xaf\x02 \x01(\x0b\x32-.api_integrations.ApiIntegrationConfig_UpdateH\x00\x12]\n create_api_integration_operation\x18\xb0\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_CreateH\x00\x12]\n update_api_integration_operation\x18\xb1\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_UpdateH\x00\x12]\n delete_api_integration_operation\x18\xb2\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_DeleteH\x00\x12K\n\x12\x63reate_translation\x18\xdf\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_CreateH\x00\x12K\n\x12update_translation\x18\xe0\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_UpdateH\x00\x12K\n\x12\x64\x65lete_translation\x18\xe1\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_DeleteH\x00\x12V\n!voice_channel_update_asr_settings\x18\xe6\x02 \x01(\x0b\x32(.channels.VoiceChannel_UpdateASRSettingsH\x00\x12S\n\x1fvoice_channel_update_disclaimer\x18\xe7\x02 \x01(\x0b\x32\'.channels.VoiceChannel_UpdateDisclaimerH\x00\x12\x44\n\x17\x63hannel_update_greeting\x18\xf8\x02 \x01(\x0b\x32 .channels.Channel_UpdateGreetingH\x00\x12K\n\x1b\x63hannel_update_style_prompt\x18\xf9\x02 \x01(\x0b\x32#.channels.Channel_UpdateStylePromptH\x00\x12O\n\x1d\x63hannel_update_safety_filters\x18\xfa\x02 \x01(\x0b\x32%.channels.Channel_UpdateSafetyFiltersH\x00\x12K\n\x1b\x63hannel_update_llm_settings\x18\xfb\x02 \x01(\x0b\x32#.channels.Channel_UpdateLLMSettingsH\x00\x12@\n\x15\x63hannel_update_status\x18\xfc\x02 \x01(\x0b\x32\x1e.channels.Channel_UpdateStatusH\x00\x12\x36\n\x12\x63sat_update_config\x18\xf2\x02 \x01(\x0b\x32\x17.csat.CSAT_UpdateConfigH\x00\x12\x41\n\x13\x63onnect_integration\x18\xf3\x02 \x01(\x0b\x32!.integrations.Integration_ConnectH\x00\x12?\n\x12\x65nable_integration\x18\xf4\x02 \x01(\x0b\x32 .integrations.Integration_EnableH\x00\x12\x41\n\x13\x64isable_integration\x18\xf7\x02 \x01(\x0b\x32!.integrations.Integration_DisableH\x00\x12R\n\x1cupdate_integration_functions\x18\xf5\x02 \x01(\x0b\x32).integrations.Integration_UpdateFunctionsH\x00\x12G\n\x16\x64isconnect_integration\x18\xf6\x02 \x01(\x0b\x32$.integrations.Integration_DisconnectH\x00\x42\t\n\x07payloadJ\x06\x08\xe2\x02\x10\xe3\x02J\x06\x08\xe3\x02\x10\xe4\x02J\x06\x08\xe4\x02\x10\xe5\x02J\x06\x08\xe5\x02\x10\xe6\x02J\x06\x08\xe8\x02\x10\xe9\x02J\x06\x08\xe9\x02\x10\xea\x02J\x06\x08\xea\x02\x10\xeb\x02J\x06\x08\xeb\x02\x10\xec\x02J\x06\x08\xec\x02\x10\xed\x02\"G\n\x0c\x43ommandBatch\x12\x1b\n\x13last_known_sequence\x18\x01 \x01(\x04\x12\x1a\n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x08.Command\"v\n\x0e\x42ranch_Created\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"r\n\x13\x42ranch_TriggerMerge\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x32\n\x0euser_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0ctriggered_by\x18\x03 \x01(\t\"\x80\x01\n\x12\x43onflictResolution\x12\x0c\n\x04path\x18\x01 \x03(\t\x12%\n\x08strategy\x18\x02 \x01(\x0e\x32\x13.ResolutionStrategy\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xbb\x01\n\rBranch_Merged\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12-\n\tmerged_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmerged_by\x18\x03 \x01(\t\x12\x15\n\rmain_sequence\x18\x04 \x01(\x04\x12\x14\n\x0csnapshot_key\x18\x05 \x01(\t\x12(\n\x0bresolutions\x18\x06 \x03(\x0b\x32\x13.ConflictResolution\"g\n\x0e\x42ranch_Deleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12.\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ndeleted_by\x18\x03 \x01(\t\"y\n\x0fProject_Created\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"\x92\x01\n\x19Project_LoadedFromJupiter\x12-\n\tloaded_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61rtifact_version\x18\x02 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"\xe2\x01\n\x13\x44\x65ploymentCompleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x12\n\nclient_env\x18\x02 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x03 \x01(\t\x12\x18\n\x10\x61rtifact_version\x18\x04 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x05 \x01(\t\x12#\n\x1b\x66unction_deployment_version\x18\x06 \x01(\t\x12!\n\x19lambda_deployment_version\x18\x08 \x01(\t\x12\x14\n\x0cversion_hash\x18\x07 \x01(\t\"\xaa\x01\n\x12\x44\x65ploymentRollback\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x03 \x01(\t\x12\x18\n\x10\x61rtifact_version\x18\x04 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x05 \x01(\t\x12#\n\x1b\x66unction_deployment_version\x18\x06 \x01(\t\x12\x14\n\x0cversion_hash\x18\x07 \x01(\t\"(\n\x10LoadedFromBundle\x12\x14\n\x0csnapshot_key\x18\x01 \x01(\t\"\x89\x01\n\x1b\x46unctionDeploymentCompleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x02 \x01(\t\x12\x1e\n\x16\x66unction_deployment_id\x18\x03 \x01(\t\x12!\n\x19lambda_deployment_version\x18\x04 \x01(\t*4\n\x12ResolutionStrategy\x12\n\n\x06theirs\x10\x00\x12\x08\n\x04ours\x10\x01\x12\x08\n\x04\x62\x61se\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EVENT'].fields_by_name['update_tts_settings']._options = None
  _globals['_EVENT'].fields_by_name['update_tts_settings']._serialized_options = b'\030\001'
  _globals['_COMMAND'].fields_by_name['update_tts_settings']._options = None
  _globals['_COMMAND'].fields_by_name['update_tts_settings']._serialized_options = b'\030\001'
  _globals['_RESOLUTIONSTRATEGY']._serialized_start=22361
  _globals['_RESOLUTIONSTRATEGY']._serialized_end=22413
  _globals['_METADATA']._serialized_start=590
  _globals['_METADATA']._serialized_end=668
  _globals['_EVENT']._serialized_start=671
  _globals['_EVENT']._serialized_end=10693
  _globals['_EVENTBATCH']._serialized_start=10695
  _globals['_EVENTBATCH']._serialized_end=10731
  _globals['_SETPROJECTION']._serialized_start=10733
  _globals['_SETPROJECTION']._serialized_end=10840
  _globals['_SOCKETERROR']._serialized_start=10842
  _globals['_SOCKETERROR']._serialized_end=10872
  _globals['_ENVELOPE']._serialized_start=10875
  _globals['_ENVELOPE']._serialized_end=11044
  _globals['_NOTIFICATION']._serialized_start=11047
  _globals['_NOTIFICATION']._serialized_end=11267
  _globals['_COMMAND']._serialized_start=11270
  _globals['_COMMAND']._serialized_end=20768
  _globals['_COMMANDBATCH']._serialized_start=20770
  _globals['_COMMANDBATCH']._serialized_end=20841
  _globals['_BRANCH_CREATED']._serialized_start=20843
  _globals['_BRANCH_CREATED']._serialized_end=20961
  _globals['_BRANCH_TRIGGERMERGE']._serialized_start=20963
  _globals['_BRANCH_TRIGGERMERGE']._serialized_end=21077
  _globals['_CONFLICTRESOLUTION']._serialized_start=21080
  _globals['_CONFLICTRESOLUTION']._serialized_end=21208
  _globals['_BRANCH_MERGED']._serialized_start=21211
  _globals['_BRANCH_MERGED']._serialized_end=21398
  _globals['_BRANCH_DELETED']._serialized_start=21400
  _globals['_BRANCH_DELETED']._serialized_end=21503
  _globals['_PROJECT_CREATED']._serialized_start=21505
  _globals['_PROJECT_CREATED']._serialized_end=21626
  _globals['_PROJECT_LOADEDFROMJUPITER']._serialized_start=21629
  _globals['_PROJECT_LOADEDFROMJUPITER']._serialized_end=21775
  _globals['_DEPLOYMENTCOMPLETED']._serialized_start=21778
  _globals['_DEPLOYMENTCOMPLETED']._serialized_end=22004
  _globals['_DEPLOYMENTROLLBACK']._serialized_start=22007
  _globals['_DEPLOYMENTROLLBACK']._serialized_end=22177
  _globals['_LOADEDFROMBUNDLE']._serialized_start=22179
  _globals['_LOADEDFROMBUNDLE']._serialized_end=22219
  _globals['_FUNCTIONDEPLOYMENTCOMPLETED']._serialized_start=22222
  _globals['_FUNCTIONDEPLOYMENTCOMPLETED']._serialized_end=22359
# @@protoc_insertion_point(module_scope)
