# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transcript_corrections.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctranscript_corrections.proto\x12\x16transcript_corrections\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\x15TranscriptCorrections\x12\x41\n\x0b\x63orrections\x18\x01 \x03(\x0b\x32,.transcript_corrections.TranscriptCorrection\"\x95\x02\n\x14TranscriptCorrection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x46\n\x13regular_expressions\x18\x04 \x03(\x0b\x32).transcript_corrections.RegularExpression\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"j\n\x11RegularExpression\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12regular_expression\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x18\n\x10replacement_type\x18\x04 \x01(\t\"\xbf\x01\n1TranscriptCorrections_CreateTranscriptCorrections\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x46\n\x13regular_expressions\x18\x04 \x03(\x0b\x32).transcript_corrections.RegularExpressionB\x0e\n\x0c_description\"\x88\x01\n1TranscriptCorrections_UpdateTranscriptCorrections\x12J\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x37.transcript_corrections.TranscriptCorrectionsUpdateDataH\x00\x88\x01\x01\x42\x07\n\x05_data\"d\n\x1fTranscriptCorrectionsUpdateData\x12\x41\n\x0b\x63orrections\x18\x01 \x03(\x0b\x32,.transcript_corrections.TranscriptCorrection\"V\n1TranscriptCorrections_DeleteTranscriptCorrections\x12!\n\x19transcript_corrections_id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transcript_corrections_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRANSCRIPTCORRECTIONS']._serialized_start=89
  _globals['_TRANSCRIPTCORRECTIONS']._serialized_end=179
  _globals['_TRANSCRIPTCORRECTION']._serialized_start=182
  _globals['_TRANSCRIPTCORRECTION']._serialized_end=459
  _globals['_REGULAREXPRESSION']._serialized_start=461
  _globals['_REGULAREXPRESSION']._serialized_end=567
  _globals['_TRANSCRIPTCORRECTIONS_CREATETRANSCRIPTCORRECTIONS']._serialized_start=570
  _globals['_TRANSCRIPTCORRECTIONS_CREATETRANSCRIPTCORRECTIONS']._serialized_end=761
  _globals['_TRANSCRIPTCORRECTIONS_UPDATETRANSCRIPTCORRECTIONS']._serialized_start=764
  _globals['_TRANSCRIPTCORRECTIONS_UPDATETRANSCRIPTCORRECTIONS']._serialized_end=900
  _globals['_TRANSCRIPTCORRECTIONSUPDATEDATA']._serialized_start=902
  _globals['_TRANSCRIPTCORRECTIONSUPDATEDATA']._serialized_end=1002
  _globals['_TRANSCRIPTCORRECTIONS_DELETETRANSCRIPTCORRECTIONS']._serialized_start=1004
  _globals['_TRANSCRIPTCORRECTIONS_DELETETRANSCRIPTCORRECTIONS']._serialized_end=1090
# @@protoc_insertion_point(module_scope)
