# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: end_function.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x65nd_function.proto\x12\x0c\x65nd_function\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0f\x66unctions.proto\"\x90\x01\n\x15\x45ndFunctionReferences\x12\x45\n\tvariables\x18\x01 \x03(\x0b\x32\x32.end_function.EndFunctionReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xf9\x02\n\x0b\x45ndFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\n \x01(\t\x12\x10\n\x08\x61rchived\x18\x0b \x01(\x08\x12\x37\n\nreferences\x18\x0c \x01(\x0b\x32#.end_function.EndFunctionReferences\"\x9e\x02\n\x12\x45ndFunction_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12\x15\n\x08\x61rchived\x18\x07 \x01(\x08H\x00\x88\x01\x01\x12<\n\nreferences\x18\x08 \x01(\x0b\x32#.end_function.EndFunctionReferencesH\x01\x88\x01\x01\x42\x0b\n\t_archivedB\r\n\x0b_references\" \n\x12\x45ndFunction_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"\xec\x01\n\x12\x45ndFunction_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x03 \x01(\tH\x01\x88\x01\x01\x12,\n\x06\x65rrors\x18\x04 \x01(\x0b\x32\x17.functions.ErrorsUpdateH\x02\x88\x01\x01\x12<\n\nreferences\x18\x05 \x01(\x0b\x32#.end_function.EndFunctionReferencesH\x03\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x07\n\x05_codeB\t\n\x07_errorsB\r\n\x0b_referencesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'end_function_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._options = None
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_ENDFUNCTIONREFERENCES']._serialized_start=87
  _globals['_ENDFUNCTIONREFERENCES']._serialized_end=231
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_start=183
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_end=231
  _globals['_ENDFUNCTION']._serialized_start=234
  _globals['_ENDFUNCTION']._serialized_end=611
  _globals['_ENDFUNCTION_CREATE']._serialized_start=614
  _globals['_ENDFUNCTION_CREATE']._serialized_end=900
  _globals['_ENDFUNCTION_DELETE']._serialized_start=902
  _globals['_ENDFUNCTION_DELETE']._serialized_end=934
  _globals['_ENDFUNCTION_UPDATE']._serialized_start=937
  _globals['_ENDFUNCTION_UPDATE']._serialized_end=1173
# @@protoc_insertion_point(module_scope)
