# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: csat.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncsat.proto\x12\x04\x63sat\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x01\n\nCSATConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0flead_in_message\x18\x02 \x01(\t\x12\x17\n\x0fsurvey_question\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\x99\x01\n\x11\x43SAT_UpdateConfig\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1c\n\x0flead_in_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fsurvey_question\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_enabledB\x12\n\x10_lead_in_messageB\x12\n\x10_survey_questionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'csat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CSATCONFIG']._serialized_start=54
  _globals['_CSATCONFIG']._serialized_end=309
  _globals['_CSAT_UPDATECONFIG']._serialized_start=312
  _globals['_CSAT_UPDATECONFIG']._serialized_end=465
# @@protoc_insertion_point(module_scope)
