# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: channels.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63hannels.proto\x12\x08\x63hannels\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\x14\x61gent_settings.proto\"\xb1\x01\n\x0bStylePrompt\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x33\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"/\n\x1dStylePrompt_UpdateStylePrompt\x12\x0e\n\x06prompt\x18\x01 \x01(\t\"\xd8\x01\n\rChannelConfig\x12/\n\x0cllm_settings\x18\x01 \x01(\x0b\x32\x19.llm_settings.LLMSettings\x12+\n\x0cstyle_prompt\x18\x02 \x01(\x0b\x32\x15.channels.StylePrompt\x12!\n\x08greeting\x18\x03 \x01(\x0b\x32\x0f.agent.Greeting\x12\x46\n\x0esafety_filters\x18\x04 \x01(\x0b\x32..content_filter_settings.ContentFilterSettings\"\x96\x01\n\x0cVoiceChannel\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.channels.ChannelConfig\x12/\n\x0c\x61sr_settings\x18\x02 \x01(\x0b\x32\x19.asr_settings.ASRSettings\x12,\n\ndisclaimer\x18\x03 \x01(\x0b\x32\x18.agent.DisclaimerMessage\"b\n\x0eWebChatChannel\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.channels.ChannelConfig\x12\'\n\x06status\x18\x02 \x01(\x0e\x32\x17.channels.ChannelStatus\"]\n\x08\x43hannels\x12%\n\x05voice\x18\x01 \x01(\x0b\x32\x16.channels.VoiceChannel\x12*\n\x08web_chat\x18\x02 \x01(\x0b\x32\x18.channels.WebChatChannel\"w\n\x16\x43hannel_UpdateGreeting\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x30\n\x08greeting\x18\x02 \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreeting\"\x87\x01\n\x19\x43hannel_UpdateStylePrompt\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12=\n\x0cstyle_prompt\x18\x02 \x01(\x0b\x32\'.channels.StylePrompt_UpdateStylePrompt\"\xae\x01\n\x1b\x43hannel_UpdateSafetyFilters\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x62\n\x0esafety_filters\x18\x02 \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettings\"\x8b\x01\n\x19\x43hannel_UpdateLLMSettings\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x41\n\x0cllm_settings\x18\x02 \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettings\"b\n\x14\x43hannel_UpdateStatus\x12\x38\n\x07webchat\x18\x01 \x01(\x0b\x32%.channels.WebChatChannel_UpdateStatusH\x00\x42\x10\n\x0e\x63hannel_status\"c\n\x1eVoiceChannel_UpdateASRSettings\x12\x41\n\x0c\x61sr_settings\x18\x01 \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettings\"e\n\x1dVoiceChannel_UpdateDisclaimer\x12\x44\n\ndisclaimer\x18\x01 \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessage\"F\n\x1bWebChatChannel_UpdateStatus\x12\'\n\x06status\x18\x01 \x01(\x0e\x32\x17.channels.ChannelStatus*&\n\x0b\x43hannelType\x12\t\n\x05VOICE\x10\x00\x12\x0c\n\x08WEB_CHAT\x10\x01*-\n\rChannelStatus\x12\x0f\n\x0bNOT_CREATED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'channels_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CHANNELTYPE']._serialized_start=1904
  _globals['_CHANNELTYPE']._serialized_end=1942
  _globals['_CHANNELSTATUS']._serialized_start=1944
  _globals['_CHANNELSTATUS']._serialized_end=1989
  _globals['_STYLEPROMPT']._serialized_start=155
  _globals['_STYLEPROMPT']._serialized_end=332
  _globals['_STYLEPROMPT_UPDATESTYLEPROMPT']._serialized_start=334
  _globals['_STYLEPROMPT_UPDATESTYLEPROMPT']._serialized_end=381
  _globals['_CHANNELCONFIG']._serialized_start=384
  _globals['_CHANNELCONFIG']._serialized_end=600
  _globals['_VOICECHANNEL']._serialized_start=603
  _globals['_VOICECHANNEL']._serialized_end=753
  _globals['_WEBCHATCHANNEL']._serialized_start=755
  _globals['_WEBCHATCHANNEL']._serialized_end=853
  _globals['_CHANNELS']._serialized_start=855
  _globals['_CHANNELS']._serialized_end=948
  _globals['_CHANNEL_UPDATEGREETING']._serialized_start=950
  _globals['_CHANNEL_UPDATEGREETING']._serialized_end=1069
  _globals['_CHANNEL_UPDATESTYLEPROMPT']._serialized_start=1072
  _globals['_CHANNEL_UPDATESTYLEPROMPT']._serialized_end=1207
  _globals['_CHANNEL_UPDATESAFETYFILTERS']._serialized_start=1210
  _globals['_CHANNEL_UPDATESAFETYFILTERS']._serialized_end=1384
  _globals['_CHANNEL_UPDATELLMSETTINGS']._serialized_start=1387
  _globals['_CHANNEL_UPDATELLMSETTINGS']._serialized_end=1526
  _globals['_CHANNEL_UPDATESTATUS']._serialized_start=1528
  _globals['_CHANNEL_UPDATESTATUS']._serialized_end=1626
  _globals['_VOICECHANNEL_UPDATEASRSETTINGS']._serialized_start=1628
  _globals['_VOICECHANNEL_UPDATEASRSETTINGS']._serialized_end=1727
  _globals['_VOICECHANNEL_UPDATEDISCLAIMER']._serialized_start=1729
  _globals['_VOICECHANNEL_UPDATEDISCLAIMER']._serialized_end=1830
  _globals['_WEBCHATCHANNEL_UPDATESTATUS']._serialized_start=1832
  _globals['_WEBCHATCHANNEL_UPDATESTATUS']._serialized_end=1902
# @@protoc_insertion_point(module_scope)
