# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: snapshot.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from poly.handlers.protobuf import handoff_pb2 as handoff__pb2
from poly.handlers.protobuf import knowledge_base_pb2 as knowledge__base__pb2
from poly.handlers.protobuf import stop_keywords_pb2 as stop__keywords__pb2
from poly.handlers.protobuf import sms_pb2 as sms__pb2
from poly.handlers.protobuf import variant_pb2 as variant__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import asr_pb2 as asr__pb2
from poly.handlers.protobuf import languages_pb2 as languages__pb2
from poly.handlers.protobuf import flows_pb2 as flows__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2
from poly.handlers.protobuf import transcript_corrections_pb2 as transcript__corrections__pb2
from poly.handlers.protobuf import experimental_config_pb2 as experimental__config__pb2
from poly.handlers.protobuf import pronunciations_pb2 as pronunciations__pb2
from poly.handlers.protobuf import keyphrase_boosting_pb2 as keyphrase__boosting__pb2
from poly.handlers.protobuf import start_function_pb2 as start__function__pb2
from poly.handlers.protobuf import end_function_pb2 as end__function__pb2
from poly.handlers.protobuf import entities_pb2 as entities__pb2
from poly.handlers.protobuf import voice_pb2 as voice__pb2
from poly.handlers.protobuf import api_integrations_pb2 as api__integrations__pb2
from poly.handlers.protobuf import variables_pb2 as variables__pb2
from poly.handlers.protobuf import translations_pb2 as translations__pb2
from poly.handlers.protobuf import channels_pb2 as channels__pb2
from poly.handlers.protobuf import csat_pb2 as csat__pb2
from poly.handlers.protobuf import integrations_pb2 as integrations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0esnapshot.proto\x12\x08snapshot\x1a\rhandoff.proto\x1a\x14knowledge_base.proto\x1a\x13stop_keywords.proto\x1a\tsms.proto\x1a\rvariant.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\tasr.proto\x1a\x0flanguages.proto\x1a\x0b\x66lows.proto\x1a\x0f\x66unctions.proto\x1a\x14\x61gent_settings.proto\x1a\x1ctranscript_corrections.proto\x1a\x19\x65xperimental_config.proto\x1a\x14pronunciations.proto\x1a\x18keyphrase_boosting.proto\x1a\x14start_function.proto\x1a\x12\x65nd_function.proto\x1a\x0e\x65ntities.proto\x1a\x0bvoice.proto\x1a\x16\x61pi_integrations.proto\x1a\x0fvariables.proto\x1a\x12translations.proto\x1a\x0e\x63hannels.proto\x1a\ncsat.proto\x1a\x12integrations.proto\"\xa6\n\n\x08Snapshot\x12#\n\x08handoffs\x18\x01 \x01(\x0b\x32\x11.handoff.Handoffs\x12\x35\n\x0eknowledge_base\x18\x02 \x01(\x0b\x32\x1d.knowledge_base.KnowledgeBase\x12\x15\n\x03sms\x18\x03 \x01(\x0b\x32\x08.sms.SMS\x12\x36\n\x12variant_management\x18\x04 \x01(\x0b\x32\x1a.variant.VariantManagement\x12\x32\n\rstop_keywords\x18\x05 \x01(\x0b\x32\x1b.stop_keywords.StopKeywords\x12/\n\x0cllm_settings\x18\x06 \x01(\x0b\x32\x19.llm_settings.LLMSettings\x12O\n\x17\x63ontent_filter_settings\x18\x07 \x01(\x0b\x32..content_filter_settings.ContentFilterSettings\x12/\n\x0c\x61sr_settings\x18\x08 \x01(\x0b\x32\x19.asr_settings.ASRSettings\x12\'\n\tlanguages\x18\t \x01(\x0b\x32\x14.languages.Languages\x12\x1b\n\x05\x66lows\x18\n \x01(\x0b\x32\x0c.flows.Flows\x12.\n\x10global_functions\x18\x0b \x01(\x0b\x32\x14.functions.Functions\x12,\n\x0e\x61gent_settings\x18\x0c \x01(\x0b\x32\x14.agent.AgentSettings\x12M\n\x16transcript_corrections\x18\r \x01(\x0b\x32-.transcript_corrections.TranscriptCorrections\x12\x44\n\x13\x65xperimental_config\x18\x0e \x01(\x0b\x32\'.experimental_config.ExperimentalConfig\x12\x36\n\x0epronunciations\x18\x0f \x01(\x0b\x32\x1e.pronunciations.Pronunciations\x12\x43\n\x13keyphrases_boosting\x18\x10 \x01(\x0b\x32&.keyphrase_boosting.KeyphrasesBoosting\x12\x35\n\x0estart_function\x18\x11 \x01(\x0b\x32\x1d.start_function.StartFunction\x12/\n\x0c\x65nd_function\x18\x12 \x01(\x0b\x32\x19.end_function.EndFunction\x12\x1d\n\x06voices\x18\x13 \x01(\x0b\x32\r.voice.Voices\x12$\n\x08\x65ntities\x18\x14 \x01(\x0b\x32\x12.entities.Entities\x12\x15\n\x03\x61sr\x18\x15 \x01(\x0b\x32\x08.asr.Asr\x12;\n\x10\x61pi_integrations\x18\x16 \x01(\x0b\x32!.api_integrations.ApiIntegrations\x12\'\n\tvariables\x18\x17 \x01(\x0b\x32\x14.variables.Variables\x12\x30\n\x0ctranslations\x18\x18 \x01(\x0b\x32\x1a.translations.Translations\x12$\n\x08\x63hannels\x18\x19 \x01(\x0b\x32\x12.channels.Channels\x12\x1e\n\x04\x63sat\x18\x1a \x01(\x0b\x32\x10.csat.CSATConfig\x12\x30\n\x0cintegrations\x18\x1b \x01(\x0b\x32\x1a.integrations.Integrationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SNAPSHOT']._serialized_start=549
  _globals['_SNAPSHOT']._serialized_end=1867
# @@protoc_insertion_point(module_scope)
