# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stop_keywords.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13stop_keywords.proto\x12\rstop_keywords\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x01\n\x15StopKeywordReferences\x12R\n\x0fglobalFunctions\x18\x01 \x03(\x0b\x32\x39.stop_keywords.StopKeywordReferences.GlobalFunctionsEntry\x1a\x36\n\x14GlobalFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"&\n\x12RegularExpressions\x12\x10\n\x08patterns\x18\x01 \x03(\t\";\n\x0cStopKeywords\x12+\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x1a.stop_keywords.StopKeyword\"\xc7\x02\n\x0bStopKeyword\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1b\n\x13regular_expressions\x18\x04 \x03(\t\x12\x12\n\nsay_phrase\x18\x05 \x01(\x08\x12\x38\n\nreferences\x18\x06 \x01(\x0b\x32$.stop_keywords.StopKeywordReferences\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\t \x01(\t\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rlanguage_code\x18\x0b \x01(\t\"\xc6\x01\n\x12StopKeyword_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1b\n\x13regular_expressions\x18\x04 \x03(\t\x12\x12\n\nsay_phrase\x18\x05 \x01(\x08\x12\x38\n\nreferences\x18\x06 \x01(\x0b\x32$.stop_keywords.StopKeywordReferences\x12\x15\n\rlanguage_code\x18\x07 \x01(\t\"\xa9\x02\n\x12StopKeyword_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\x05title\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x13regular_expressions\x18\x04 \x03(\t\x12\x17\n\nsay_phrase\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12=\n\nreferences\x18\x06 \x01(\x0b\x32$.stop_keywords.StopKeywordReferencesH\x03\x88\x01\x01\x12\x1a\n\rlanguage_code\x18\x07 \x01(\tH\x04\x88\x01\x01\x42\x08\n\x06_titleB\x0e\n\x0c_descriptionB\r\n\x0b_say_phraseB\r\n\x0b_referencesB\x10\n\x0e_language_code\" \n\x12StopKeyword_Delete\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stop_keywords_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STOPKEYWORDREFERENCES_GLOBALFUNCTIONSENTRY']._options = None
  _globals['_STOPKEYWORDREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_STOPKEYWORDREFERENCES']._serialized_start=72
  _globals['_STOPKEYWORDREFERENCES']._serialized_end=235
  _globals['_STOPKEYWORDREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_start=181
  _globals['_STOPKEYWORDREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_end=235
  _globals['_REGULAREXPRESSIONS']._serialized_start=237
  _globals['_REGULAREXPRESSIONS']._serialized_end=275
  _globals['_STOPKEYWORDS']._serialized_start=277
  _globals['_STOPKEYWORDS']._serialized_end=336
  _globals['_STOPKEYWORD']._serialized_start=339
  _globals['_STOPKEYWORD']._serialized_end=666
  _globals['_STOPKEYWORD_CREATE']._serialized_start=669
  _globals['_STOPKEYWORD_CREATE']._serialized_end=867
  _globals['_STOPKEYWORD_UPDATE']._serialized_start=870
  _globals['_STOPKEYWORD_UPDATE']._serialized_end=1167
  _globals['_STOPKEYWORD_DELETE']._serialized_start=1169
  _globals['_STOPKEYWORD_DELETE']._serialized_end=1201
# @@protoc_insertion_point(module_scope)
