# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_settings.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61gent_settings.proto\x12\x05\x61gent\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe5\x02\n\rAgentSettings\x12!\n\x08greeting\x18\x01 \x03(\x0b\x32\x0f.agent.Greeting\x12\'\n\x0bpersonality\x18\x02 \x01(\x0b\x32\x12.agent.Personality\x12\x19\n\x04role\x18\x03 \x01(\x0b\x32\x0b.agent.Role\x12\x34\n\x12\x64isclaimer_message\x18\x04 \x03(\x0b\x32\x18.agent.DisclaimerMessage\x12\x1b\n\x05rules\x18\x05 \x01(\x0b\x32\x0c.agent.Rules\x12G\n\x12language_behaviors\x18\x06 \x03(\x0b\x32+.agent.AgentSettings.LanguageBehaviorsEntry\x1aQ\n\x16LanguageBehaviorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.agent.LanguageBehavior:\x02\x38\x01\"\x91\x02\n\x08Greeting\x12\x17\n\x0fwelcome_message\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x33\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x32\n\nreferences\x18\x06 \x01(\x0b\x32\x19.agent.GreetingReferencesH\x02\x88\x01\x01\x12\x15\n\rlanguage_code\x18\x07 \x01(\tB\r\n\x0b_updated_atB\r\n\x0b_updated_byB\r\n\x0b_references\"\xa5\x01\n\x17Greeting_UpdateGreeting\x12\x1c\n\x0fwelcome_message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x32\n\nreferences\x18\x02 \x01(\x0b\x32\x19.agent.GreetingReferencesH\x01\x88\x01\x01\x12\x15\n\rlanguage_code\x18\x03 \x01(\tB\x12\n\x10_welcome_messageB\r\n\x0b_references\"\x83\x01\n\x12GreetingReferences\x12;\n\tvariables\x18\x01 \x03(\x0b\x32(.agent.GreetingReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"j\n\nAdjectives\x12-\n\x06values\x18\x01 \x03(\x0b\x32\x1d.agent.Adjectives.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xe2\x02\n\x0bPersonality\x12\x36\n\nadjectives\x18\x01 \x03(\x0b\x32\".agent.Personality.AdjectivesEntry\x12\x0e\n\x06\x63ustom\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x33\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x35\n\nreferences\x18\x07 \x01(\x0b\x32\x1c.agent.PersonalityReferencesH\x02\x88\x01\x01\x1a\x31\n\x0f\x41\x64jectivesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_byB\r\n\x0b_references\"\xc0\x01\n\x1dPersonality_UpdatePersonality\x12*\n\nadjectives\x18\x01 \x01(\x0b\x32\x11.agent.AdjectivesH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x35\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.agent.PersonalityReferencesH\x02\x88\x01\x01\x42\r\n\x0b_adjectivesB\t\n\x07_customB\r\n\x0b_references\"\x89\x01\n\x15PersonalityReferences\x12>\n\tvariables\x18\x01 \x03(\x0b\x32+.agent.PersonalityReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x91\x02\n\x04Role\x12\r\n\x05value\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x12.\n\nreferences\x18\x08 \x01(\x0b\x32\x15.agent.RoleReferencesH\x02\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_byB\r\n\x0b_references\"\xc0\x01\n\x0fRole_UpdateRole\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\tH\x02\x88\x01\x01\x12.\n\nreferences\x18\x04 \x01(\x0b\x32\x15.agent.RoleReferencesH\x03\x88\x01\x01\x42\x08\n\x06_valueB\x12\n\x10_additional_infoB\t\n\x07_customB\r\n\x0b_references\"{\n\x0eRoleReferences\x12\x37\n\tvariables\x18\x01 \x03(\x0b\x32$.agent.RoleReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x8d\x02\n\x11\x44isclaimerMessage\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12(\n\x0cringing_tone\x18\x03 \x01(\x0b\x32\x12.agent.AudioToPlay\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x12\x15\n\rlanguage_code\x18\x08 \x01(\tB\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xd2\x01\n)DisclaimerMessage_UpdateDisclaimerMessage\x12\x17\n\nis_enabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0cringing_tone\x18\x03 \x01(\x0b\x32\x18.agent.UpdateRingingToneH\x02\x88\x01\x01\x12\x15\n\rlanguage_code\x18\x04 \x01(\tB\r\n\x0b_is_enabledB\n\n\x08_messageB\x0f\n\r_ringing_tone\"\x93\x01\n\x11UpdateRingingTone\x12\x14\n\x07s3_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11original_filename\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\npublic_url\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_s3_pathB\x14\n\x12_original_filenameB\r\n\x0b_public_url\"M\n\x0b\x41udioToPlay\x12\x0f\n\x07s3_path\x18\x01 \x01(\t\x12\x19\n\x11original_filename\x18\x02 \x01(\t\x12\x12\n\npublic_url\x18\x03 \x01(\t\"\xaa\x04\n\x0fRulesReferences\x12,\n\x03sms\x18\x01 \x03(\x0b\x32\x1f.agent.RulesReferences.SmsEntry\x12\x34\n\x07handoff\x18\x02 \x03(\x0b\x32#.agent.RulesReferences.HandoffEntry\x12:\n\nattributes\x18\x03 \x03(\x0b\x32&.agent.RulesReferences.AttributesEntry\x12\x44\n\x0fglobalFunctions\x18\x04 \x03(\x0b\x32+.agent.RulesReferences.GlobalFunctionsEntry\x12\x38\n\tvariables\x18\x05 \x03(\x0b\x32%.agent.RulesReferences.VariablesEntry\x1a*\n\x08SmsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a.\n\x0cHandoffEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14GlobalFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xda\x01\n\x05Rules\x12\x11\n\tbehaviour\x18\x01 \x01(\t\x12*\n\nreferences\x18\x02 \x01(\x0b\x32\x16.agent.RulesReferences\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x33\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"y\n\x11Rules_UpdateRules\x12\x16\n\tbehaviour\x18\x01 \x01(\tH\x00\x88\x01\x01\x12/\n\nreferences\x18\x02 \x01(\x0b\x32\x16.agent.RulesReferencesH\x01\x88\x01\x01\x42\x0c\n\n_behaviourB\r\n\x0b_references\"\xec\x04\n\x1aLanguageBehaviorReferences\x12\x37\n\x03sms\x18\x01 \x03(\x0b\x32*.agent.LanguageBehaviorReferences.SmsEntry\x12?\n\x07handoff\x18\x02 \x03(\x0b\x32..agent.LanguageBehaviorReferences.HandoffEntry\x12\x45\n\nattributes\x18\x03 \x03(\x0b\x32\x31.agent.LanguageBehaviorReferences.AttributesEntry\x12O\n\x0fglobalFunctions\x18\x04 \x03(\x0b\x32\x36.agent.LanguageBehaviorReferences.GlobalFunctionsEntry\x12\x43\n\tvariables\x18\x05 \x03(\x0b\x32\x30.agent.LanguageBehaviorReferences.VariablesEntry\x1a*\n\x08SmsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a.\n\x0cHandoffEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14GlobalFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xa9\x02\n\x10LanguageBehavior\x12\x17\n\x0f\x62\x65havior_prompt\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x33\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x35\n\nreferences\x18\x07 \x01(\x0b\x32!.agent.LanguageBehaviorReferencesB\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xbd\x01\n\'LanguageBehavior_UpdateLanguageBehavior\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x1c\n\x0f\x62\x65havior_prompt\x18\x02 \x01(\tH\x00\x88\x01\x01\x12:\n\nreferences\x18\x03 \x01(\x0b\x32!.agent.LanguageBehaviorReferencesH\x01\x88\x01\x01\x42\x12\n\x10_behavior_promptB\r\n\x0b_referencesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._options = None
  _globals['_AGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_options = b'8\001'
  _globals['_GREETINGREFERENCES_VARIABLESENTRY']._options = None
  _globals['_GREETINGREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_ADJECTIVES_VALUESENTRY']._options = None
  _globals['_ADJECTIVES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_PERSONALITY_ADJECTIVESENTRY']._options = None
  _globals['_PERSONALITY_ADJECTIVESENTRY']._serialized_options = b'8\001'
  _globals['_PERSONALITYREFERENCES_VARIABLESENTRY']._options = None
  _globals['_PERSONALITYREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_ROLEREFERENCES_VARIABLESENTRY']._options = None
  _globals['_ROLEREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_RULESREFERENCES_SMSENTRY']._options = None
  _globals['_RULESREFERENCES_SMSENTRY']._serialized_options = b'8\001'
  _globals['_RULESREFERENCES_HANDOFFENTRY']._options = None
  _globals['_RULESREFERENCES_HANDOFFENTRY']._serialized_options = b'8\001'
  _globals['_RULESREFERENCES_ATTRIBUTESENTRY']._options = None
  _globals['_RULESREFERENCES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_RULESREFERENCES_GLOBALFUNCTIONSENTRY']._options = None
  _globals['_RULESREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_RULESREFERENCES_VARIABLESENTRY']._options = None
  _globals['_RULESREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_LANGUAGEBEHAVIORREFERENCES_SMSENTRY']._options = None
  _globals['_LANGUAGEBEHAVIORREFERENCES_SMSENTRY']._serialized_options = b'8\001'
  _globals['_LANGUAGEBEHAVIORREFERENCES_HANDOFFENTRY']._options = None
  _globals['_LANGUAGEBEHAVIORREFERENCES_HANDOFFENTRY']._serialized_options = b'8\001'
  _globals['_LANGUAGEBEHAVIORREFERENCES_ATTRIBUTESENTRY']._options = None
  _globals['_LANGUAGEBEHAVIORREFERENCES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_LANGUAGEBEHAVIORREFERENCES_GLOBALFUNCTIONSENTRY']._options = None
  _globals['_LANGUAGEBEHAVIORREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_LANGUAGEBEHAVIORREFERENCES_VARIABLESENTRY']._options = None
  _globals['_LANGUAGEBEHAVIORREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_AGENTSETTINGS']._serialized_start=65
  _globals['_AGENTSETTINGS']._serialized_end=422
  _globals['_AGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_start=341
  _globals['_AGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_end=422
  _globals['_GREETING']._serialized_start=425
  _globals['_GREETING']._serialized_end=698
  _globals['_GREETING_UPDATEGREETING']._serialized_start=701
  _globals['_GREETING_UPDATEGREETING']._serialized_end=866
  _globals['_GREETINGREFERENCES']._serialized_start=869
  _globals['_GREETINGREFERENCES']._serialized_end=1000
  _globals['_GREETINGREFERENCES_VARIABLESENTRY']._serialized_start=952
  _globals['_GREETINGREFERENCES_VARIABLESENTRY']._serialized_end=1000
  _globals['_ADJECTIVES']._serialized_start=1002
  _globals['_ADJECTIVES']._serialized_end=1108
  _globals['_ADJECTIVES_VALUESENTRY']._serialized_start=1063
  _globals['_ADJECTIVES_VALUESENTRY']._serialized_end=1108
  _globals['_PERSONALITY']._serialized_start=1111
  _globals['_PERSONALITY']._serialized_end=1465
  _globals['_PERSONALITY_ADJECTIVESENTRY']._serialized_start=1371
  _globals['_PERSONALITY_ADJECTIVESENTRY']._serialized_end=1420
  _globals['_PERSONALITY_UPDATEPERSONALITY']._serialized_start=1468
  _globals['_PERSONALITY_UPDATEPERSONALITY']._serialized_end=1660
  _globals['_PERSONALITYREFERENCES']._serialized_start=1663
  _globals['_PERSONALITYREFERENCES']._serialized_end=1800
  _globals['_PERSONALITYREFERENCES_VARIABLESENTRY']._serialized_start=952
  _globals['_PERSONALITYREFERENCES_VARIABLESENTRY']._serialized_end=1000
  _globals['_ROLE']._serialized_start=1803
  _globals['_ROLE']._serialized_end=2076
  _globals['_ROLE_UPDATEROLE']._serialized_start=2079
  _globals['_ROLE_UPDATEROLE']._serialized_end=2271
  _globals['_ROLEREFERENCES']._serialized_start=2273
  _globals['_ROLEREFERENCES']._serialized_end=2396
  _globals['_ROLEREFERENCES_VARIABLESENTRY']._serialized_start=952
  _globals['_ROLEREFERENCES_VARIABLESENTRY']._serialized_end=1000
  _globals['_DISCLAIMERMESSAGE']._serialized_start=2399
  _globals['_DISCLAIMERMESSAGE']._serialized_end=2668
  _globals['_DISCLAIMERMESSAGE_UPDATEDISCLAIMERMESSAGE']._serialized_start=2671
  _globals['_DISCLAIMERMESSAGE_UPDATEDISCLAIMERMESSAGE']._serialized_end=2881
  _globals['_UPDATERINGINGTONE']._serialized_start=2884
  _globals['_UPDATERINGINGTONE']._serialized_end=3031
  _globals['_AUDIOTOPLAY']._serialized_start=3033
  _globals['_AUDIOTOPLAY']._serialized_end=3110
  _globals['_RULESREFERENCES']._serialized_start=3113
  _globals['_RULESREFERENCES']._serialized_end=3667
  _globals['_RULESREFERENCES_SMSENTRY']._serialized_start=3420
  _globals['_RULESREFERENCES_SMSENTRY']._serialized_end=3462
  _globals['_RULESREFERENCES_HANDOFFENTRY']._serialized_start=3464
  _globals['_RULESREFERENCES_HANDOFFENTRY']._serialized_end=3510
  _globals['_RULESREFERENCES_ATTRIBUTESENTRY']._serialized_start=3512
  _globals['_RULESREFERENCES_ATTRIBUTESENTRY']._serialized_end=3561
  _globals['_RULESREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_start=3563
  _globals['_RULESREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_end=3617
  _globals['_RULESREFERENCES_VARIABLESENTRY']._serialized_start=952
  _globals['_RULESREFERENCES_VARIABLESENTRY']._serialized_end=1000
  _globals['_RULES']._serialized_start=3670
  _globals['_RULES']._serialized_end=3888
  _globals['_RULES_UPDATERULES']._serialized_start=3890
  _globals['_RULES_UPDATERULES']._serialized_end=4011
  _globals['_LANGUAGEBEHAVIORREFERENCES']._serialized_start=4014
  _globals['_LANGUAGEBEHAVIORREFERENCES']._serialized_end=4634
  _globals['_LANGUAGEBEHAVIORREFERENCES_SMSENTRY']._serialized_start=3420
  _globals['_LANGUAGEBEHAVIORREFERENCES_SMSENTRY']._serialized_end=3462
  _globals['_LANGUAGEBEHAVIORREFERENCES_HANDOFFENTRY']._serialized_start=3464
  _globals['_LANGUAGEBEHAVIORREFERENCES_HANDOFFENTRY']._serialized_end=3510
  _globals['_LANGUAGEBEHAVIORREFERENCES_ATTRIBUTESENTRY']._serialized_start=3512
  _globals['_LANGUAGEBEHAVIORREFERENCES_ATTRIBUTESENTRY']._serialized_end=3561
  _globals['_LANGUAGEBEHAVIORREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_start=3563
  _globals['_LANGUAGEBEHAVIORREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_end=3617
  _globals['_LANGUAGEBEHAVIORREFERENCES_VARIABLESENTRY']._serialized_start=952
  _globals['_LANGUAGEBEHAVIORREFERENCES_VARIABLESENTRY']._serialized_end=1000
  _globals['_LANGUAGEBEHAVIOR']._serialized_start=4637
  _globals['_LANGUAGEBEHAVIOR']._serialized_end=4934
  _globals['_LANGUAGEBEHAVIOR_UPDATELANGUAGEBEHAVIOR']._serialized_start=4937
  _globals['_LANGUAGEBEHAVIOR_UPDATELANGUAGEBEHAVIOR']._serialized_end=5126
# @@protoc_insertion_point(module_scope)
