# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: poly_platform/ragdoll/pb/ragdoll_service_grpc.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly_platform.ragdoll.pb import ragdoll_types_pb2 as poly__platform_dot_ragdoll_dot_pb_dot_ragdoll__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3poly_platform/ragdoll/pb/ragdoll_service_grpc.proto\x12\x07ragdoll\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,poly_platform/ragdoll/pb/ragdoll_types.proto\":\n\x05\x45rror\x12 \n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.ragdoll.ErrorCode\x12\x0f\n\x07message\x18\x02 \x01(\t\"K\n\x10ListTopicsParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x91\x01\n\x10ListTopicsOutput\x12\x1e\n\x06topics\x18\x01 \x03(\x0b\x32\x0e.ragdoll.Topic\x12-\n\x15uninstantiated_topics\x18\x03 \x03(\x0b\x32\x0e.ragdoll.Topic\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"u\n\x12ListTopicsResponse\x12+\n\x06output\x18\x01 \x01(\x0b\x32\x19.ragdoll.ListTopicsOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"\xaa\x01\n\x11QueryTopicsParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\nquery_text\x18\x04 \x01(\t\x12\r\n\x05top_k\x18\x05 \x01(\r\x12\x11\n\tthreshold\x18\x06 \x01(\x02\x12\x12\n\nvariant_id\x18\x07 \x01(\t\x12\x12\n\nclient_env\x18\x08 \x01(\t\"C\n\x10QueryTopicResult\x12\x1d\n\x05topic\x18\x01 \x01(\x0b\x32\x0e.ragdoll.Topic\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\"Y\n\x11QueryTopicsOutput\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.ragdoll.QueryTopicResult\x12\x18\n\x10required_loading\x18\x02 \x01(\x08\"w\n\x13QueryTopicsResponse\x12,\n\x06output\x18\x01 \x01(\x0b\x32\x1a.ragdoll.QueryTopicsOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"`\n\x11\x45nsureReadyParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\nclient_env\x18\x04 \x01(\t\"-\n\x11\x45nsureReadyOutput\x12\x18\n\x10required_loading\x18\x01 \x01(\x08\"w\n\x13\x45nsureReadyResponse\x12,\n\x06output\x18\x01 \x01(\x0b\x32\x1a.ragdoll.EnsureReadyOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"\xc4\x02\n\x12UpdateTopicsParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x19\n\x11version_to_create\x18\x04 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x05 \x01(\x08\x12%\n\rcreate_topics\x18\x06 \x03(\x0b\x32\x0e.ragdoll.Topic\x12%\n\rupdate_topics\x18\x07 \x03(\x0b\x32\x0e.ragdoll.Topic\x12\x18\n\x10\x64\x65lete_topic_ids\x18\x08 \x03(\t\x12\x32\n\x0enew_updated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x15uninstantiated_topics\x18\n \x03(\x0b\x32\x0e.ragdoll.Topic\"\x87\x01\n\x12UpdateTopicsOutput\x12\x13\n\x0bnum_created\x18\x01 \x01(\r\x12\x13\n\x0bnum_deleted\x18\x02 \x01(\r\x12\x13\n\x0bnum_updated\x18\x03 \x01(\r\x12\x32\n\x0enew_updated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"y\n\x14UpdateTopicsResponse\x12-\n\x06output\x18\x01 \x01(\x0b\x32\x1b.ragdoll.UpdateTopicsOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"\xab\x01\n\x15\x43reateEphemeralParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x19\n\x11version_to_create\x18\x04 \x01(\t\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x65xpiry\x18\x06 \x01(\r\"[\n\x15\x43reateEphemeralOutput\x12\x12\n\nindex_size\x18\x01 \x01(\r\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x7f\n\x17\x43reateEphemeralResponse\x12\x30\n\x06output\x18\x01 \x01(\x0b\x32\x1e.ragdoll.CreateEphemeralOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"\xd2\x02\n\x13UpdateInplaceParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x37\n\x13\x65xpected_updated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0enew_updated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\rcreate_topics\x18\x06 \x03(\x0b\x32\x0e.ragdoll.Topic\x12%\n\rupdate_topics\x18\x07 \x03(\x0b\x32\x0e.ragdoll.Topic\x12\x18\n\x10\x64\x65lete_topic_ids\x18\x08 \x03(\t\x12-\n\x15uninstantiated_topics\x18\t \x03(\x0b\x32\x0e.ragdoll.Topic\"\xf1\x01\n\x13UpdateInplaceOutput\x12\x13\n\x0bnum_created\x18\x01 \x01(\r\x12\x13\n\x0bnum_deleted\x18\x02 \x01(\r\x12\x13\n\x0bnum_updated\x18\x03 \x01(\r\x12\x32\n\x0enew_updated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x19\x63reate_topics_warning_ids\x18\x05 \x03(\t\x12!\n\x19update_topics_warning_ids\x18\x06 \x03(\t\x12!\n\x19\x64\x65lete_topics_warning_ids\x18\x07 \x03(\t\"{\n\x15UpdateInplaceResponse\x12.\n\x06output\x18\x01 \x01(\x0b\x32\x1c.ragdoll.UpdateInplaceOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"L\n\x11GetMetadataParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"W\n\x11GetMetadataOutput\x12\x12\n\nindex_size\x18\x01 \x01(\r\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"v\n\x12GetMetadataReponse\x12,\n\x06output\x18\x01 \x01(\x0b\x32\x1a.ragdoll.GetMetadataOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"M\n\x12\x44\x65leteCachedParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x14\n\x12\x44\x65leteCachedOutput\"y\n\x14\x44\x65leteCachedResponse\x12-\n\x06output\x18\x01 \x01(\x0b\x32\x1b.ragdoll.DeleteCachedOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"e\n\x11UpdateModelParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x17\n\x0f\x65mbedding_model\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\x13\n\x11UpdateModelOutput\"w\n\x13UpdateModelResponse\x12,\n\x06output\x18\x01 \x01(\x0b\x32\x1a.ragdoll.UpdateModelOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error\"F\n\x0bTextToEmbed\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\tB\x07\n\x05_name\"x\n\x10\x45mbedTextsParams\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x17\n\x0f\x65mbedding_model\x18\x03 \x01(\t\x12#\n\x05texts\x18\x04 \x03(\x0b\x32\x14.ragdoll.TextToEmbed\"!\n\x0c\x45mbeddedText\x12\x11\n\tembedding\x18\x01 \x01(\x0c\"A\n\x10\x45mbedTextsOutput\x12-\n\x0e\x65mbedded_texts\x18\x01 \x03(\x0b\x32\x15.ragdoll.EmbeddedText\"u\n\x12\x45mbedTextsResponse\x12+\n\x06output\x18\x01 \x01(\x0b\x32\x19.ragdoll.EmbedTextsOutputH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.ragdoll.ErrorH\x00\x42\x11\n\x0foutput_or_error*\x95\x01\n\tErrorCode\x12\x08\n\x04NONE\x10\x00\x12\x1d\n\x19KNOWLEDGE_BASE_NOT_EXISTS\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x11\n\rREDIS_TIMEOUT\x10\x03\x12\x13\n\x0f\x43OMPUTE_TIMEOUT\x10\x04\x12!\n\x1dKNOWLEDGE_BASE_ALREADY_EXISTS\x10\x05\x32\x99\x06\n\x0eRagdollService\x12G\n\x0blist_topics\x12\x19.ragdoll.ListTopicsParams\x1a\x1b.ragdoll.ListTopicsResponse\"\x00\x12M\n\rupdate_topics\x12\x1b.ragdoll.UpdateTopicsParams\x1a\x1d.ragdoll.UpdateTopicsResponse\"\x00\x12J\n\x0cquery_topics\x12\x1a.ragdoll.QueryTopicsParams\x1a\x1c.ragdoll.QueryTopicsResponse\"\x00\x12J\n\x0c\x65nsure_ready\x12\x1a.ragdoll.EnsureReadyParams\x1a\x1c.ragdoll.EnsureReadyResponse\"\x00\x12V\n\x10\x63reate_ephemeral\x12\x1e.ragdoll.CreateEphemeralParams\x1a .ragdoll.CreateEphemeralResponse\"\x00\x12P\n\x0eupdate_inplace\x12\x1c.ragdoll.UpdateInplaceParams\x1a\x1e.ragdoll.UpdateInplaceResponse\"\x00\x12I\n\x0cget_metadata\x12\x1a.ragdoll.GetMetadataParams\x1a\x1b.ragdoll.GetMetadataReponse\"\x00\x12M\n\rdelete_cached\x12\x1b.ragdoll.DeleteCachedParams\x1a\x1d.ragdoll.DeleteCachedResponse\"\x00\x12J\n\x0cupdate_model\x12\x1a.ragdoll.UpdateModelParams\x1a\x1c.ragdoll.UpdateModelResponse\"\x00\x12G\n\x0b\x65mbed_texts\x12\x19.ragdoll.EmbedTextsParams\x1a\x1b.ragdoll.EmbedTextsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'poly_platform.ragdoll.pb.ragdoll_service_grpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ERRORCODE']._serialized_start=4133
  _globals['_ERRORCODE']._serialized_end=4282
  _globals['_ERROR']._serialized_start=143
  _globals['_ERROR']._serialized_end=201
  _globals['_LISTTOPICSPARAMS']._serialized_start=203
  _globals['_LISTTOPICSPARAMS']._serialized_end=278
  _globals['_LISTTOPICSOUTPUT']._serialized_start=281
  _globals['_LISTTOPICSOUTPUT']._serialized_end=426
  _globals['_LISTTOPICSRESPONSE']._serialized_start=428
  _globals['_LISTTOPICSRESPONSE']._serialized_end=545
  _globals['_QUERYTOPICSPARAMS']._serialized_start=548
  _globals['_QUERYTOPICSPARAMS']._serialized_end=718
  _globals['_QUERYTOPICRESULT']._serialized_start=720
  _globals['_QUERYTOPICRESULT']._serialized_end=787
  _globals['_QUERYTOPICSOUTPUT']._serialized_start=789
  _globals['_QUERYTOPICSOUTPUT']._serialized_end=878
  _globals['_QUERYTOPICSRESPONSE']._serialized_start=880
  _globals['_QUERYTOPICSRESPONSE']._serialized_end=999
  _globals['_ENSUREREADYPARAMS']._serialized_start=1001
  _globals['_ENSUREREADYPARAMS']._serialized_end=1097
  _globals['_ENSUREREADYOUTPUT']._serialized_start=1099
  _globals['_ENSUREREADYOUTPUT']._serialized_end=1144
  _globals['_ENSUREREADYRESPONSE']._serialized_start=1146
  _globals['_ENSUREREADYRESPONSE']._serialized_end=1265
  _globals['_UPDATETOPICSPARAMS']._serialized_start=1268
  _globals['_UPDATETOPICSPARAMS']._serialized_end=1592
  _globals['_UPDATETOPICSOUTPUT']._serialized_start=1595
  _globals['_UPDATETOPICSOUTPUT']._serialized_end=1730
  _globals['_UPDATETOPICSRESPONSE']._serialized_start=1732
  _globals['_UPDATETOPICSRESPONSE']._serialized_end=1853
  _globals['_CREATEEPHEMERALPARAMS']._serialized_start=1856
  _globals['_CREATEEPHEMERALPARAMS']._serialized_end=2027
  _globals['_CREATEEPHEMERALOUTPUT']._serialized_start=2029
  _globals['_CREATEEPHEMERALOUTPUT']._serialized_end=2120
  _globals['_CREATEEPHEMERALRESPONSE']._serialized_start=2122
  _globals['_CREATEEPHEMERALRESPONSE']._serialized_end=2249
  _globals['_UPDATEINPLACEPARAMS']._serialized_start=2252
  _globals['_UPDATEINPLACEPARAMS']._serialized_end=2590
  _globals['_UPDATEINPLACEOUTPUT']._serialized_start=2593
  _globals['_UPDATEINPLACEOUTPUT']._serialized_end=2834
  _globals['_UPDATEINPLACERESPONSE']._serialized_start=2836
  _globals['_UPDATEINPLACERESPONSE']._serialized_end=2959
  _globals['_GETMETADATAPARAMS']._serialized_start=2961
  _globals['_GETMETADATAPARAMS']._serialized_end=3037
  _globals['_GETMETADATAOUTPUT']._serialized_start=3039
  _globals['_GETMETADATAOUTPUT']._serialized_end=3126
  _globals['_GETMETADATAREPONSE']._serialized_start=3128
  _globals['_GETMETADATAREPONSE']._serialized_end=3246
  _globals['_DELETECACHEDPARAMS']._serialized_start=3248
  _globals['_DELETECACHEDPARAMS']._serialized_end=3325
  _globals['_DELETECACHEDOUTPUT']._serialized_start=3327
  _globals['_DELETECACHEDOUTPUT']._serialized_end=3347
  _globals['_DELETECACHEDRESPONSE']._serialized_start=3349
  _globals['_DELETECACHEDRESPONSE']._serialized_end=3470
  _globals['_UPDATEMODELPARAMS']._serialized_start=3472
  _globals['_UPDATEMODELPARAMS']._serialized_end=3573
  _globals['_UPDATEMODELOUTPUT']._serialized_start=3575
  _globals['_UPDATEMODELOUTPUT']._serialized_end=3594
  _globals['_UPDATEMODELRESPONSE']._serialized_start=3596
  _globals['_UPDATEMODELRESPONSE']._serialized_end=3715
  _globals['_TEXTTOEMBED']._serialized_start=3717
  _globals['_TEXTTOEMBED']._serialized_end=3787
  _globals['_EMBEDTEXTSPARAMS']._serialized_start=3789
  _globals['_EMBEDTEXTSPARAMS']._serialized_end=3909
  _globals['_EMBEDDEDTEXT']._serialized_start=3911
  _globals['_EMBEDDEDTEXT']._serialized_end=3944
  _globals['_EMBEDTEXTSOUTPUT']._serialized_start=3946
  _globals['_EMBEDTEXTSOUTPUT']._serialized_end=4011
  _globals['_EMBEDTEXTSRESPONSE']._serialized_start=4013
  _globals['_EMBEDTEXTSRESPONSE']._serialized_end=4130
  _globals['_RAGDOLLSERVICE']._serialized_start=4285
  _globals['_RAGDOLLSERVICE']._serialized_end=5078
# @@protoc_insertion_point(module_scope)
