# Copyright PolyAI Limited
# flake8: noqa
# ruff: noqa
# type: ignore
__all__ = ["AgentResponse", "UserInput"]


class UserInput:
    """Object representing a user turn"""

    def __init__(self, text: str) -> None: ...
    @property
    def text(self) -> str: ...
    @property
    def role(self) -> str: ...
    def to_dict(self) -> dict[str, str]: ...
    def to_string(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...


class AgentResponse:
    """Object representing an agent turn"""

    def __init__(self, text: str) -> None: ...
    @property
    def text(self) -> str: ...
    @property
    def role(self) -> str: ...
    def to_dict(self) -> dict[str, str]: ...
    def to_string(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
