# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: entities.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x65ntities.proto\x12\x08\x65ntities\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfb\x01\n\x10\x45ntityReferences\x12=\n\nflow_steps\x18\x01 \x03(\x0b\x32).entities.EntityReferences.FlowStepsEntry\x12\x42\n\rno_code_steps\x18\x02 \x03(\x0b\x32+.entities.EntityReferences.NoCodeStepsEntry\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x32\n\x10NoCodeStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\".\n\x08\x45ntities\x12\"\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x10.entities.Entity\"\xa2\x05\n\x06\x45ntity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nreferences\x18\t \x01(\x0b\x32\x1a.entities.EntityReferences\x12)\n\x07numeric\x18\n \x01(\x0b\x32\x16.entities.NumberConfigH\x00\x12\x34\n\x0c\x61lphanumeric\x18\x0b \x01(\x0b\x32\x1c.entities.AlphanumericConfigH\x00\x12/\n\x04\x65num\x18\x0c \x01(\x0b\x32\x1f.entities.MultipleOptionsConfigH\x00\x12$\n\x04\x64\x61te\x18\r \x01(\x0b\x32\x14.entities.DateConfigH\x00\x12\x33\n\x0cphone_number\x18\x0e \x01(\x0b\x32\x1b.entities.PhoneNumberConfigH\x00\x12$\n\x04time\x18\x0f \x01(\x0b\x32\x14.entities.TimeConfigH\x00\x12*\n\x07\x61\x64\x64ress\x18\x10 \x01(\x0b\x32\x17.entities.AddressConfigH\x00\x12-\n\tfree_text\x18\x11 \x01(\x0b\x32\x18.entities.FreeTextConfigH\x00\x12+\n\x0bname_config\x18\x12 \x01(\x0b\x32\x14.entities.NameConfigH\x00\x42\x08\n\x06\x63onfig\"\xa1\x04\n\rEntity_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.entities.EntityReferences\x12)\n\x07numeric\x18\x06 \x01(\x0b\x32\x16.entities.NumberConfigH\x00\x12\x34\n\x0c\x61lphanumeric\x18\x07 \x01(\x0b\x32\x1c.entities.AlphanumericConfigH\x00\x12/\n\x04\x65num\x18\x08 \x01(\x0b\x32\x1f.entities.MultipleOptionsConfigH\x00\x12$\n\x04\x64\x61te\x18\t \x01(\x0b\x32\x14.entities.DateConfigH\x00\x12\x33\n\x0cphone_number\x18\n \x01(\x0b\x32\x1b.entities.PhoneNumberConfigH\x00\x12$\n\x04time\x18\x0b \x01(\x0b\x32\x14.entities.TimeConfigH\x00\x12*\n\x07\x61\x64\x64ress\x18\x0c \x01(\x0b\x32\x17.entities.AddressConfigH\x00\x12-\n\tfree_text\x18\r \x01(\x0b\x32\x18.entities.FreeTextConfigH\x00\x12+\n\x0bname_config\x18\x0e \x01(\x0b\x32\x14.entities.NameConfigH\x00\x42\x08\n\x06\x63onfig\"\xa1\x04\n\rEntity_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.entities.EntityReferences\x12)\n\x07numeric\x18\x06 \x01(\x0b\x32\x16.entities.NumberConfigH\x00\x12\x34\n\x0c\x61lphanumeric\x18\x07 \x01(\x0b\x32\x1c.entities.AlphanumericConfigH\x00\x12/\n\x04\x65num\x18\x08 \x01(\x0b\x32\x1f.entities.MultipleOptionsConfigH\x00\x12$\n\x04\x64\x61te\x18\t \x01(\x0b\x32\x14.entities.DateConfigH\x00\x12\x33\n\x0cphone_number\x18\n \x01(\x0b\x32\x1b.entities.PhoneNumberConfigH\x00\x12$\n\x04time\x18\x0b \x01(\x0b\x32\x14.entities.TimeConfigH\x00\x12*\n\x07\x61\x64\x64ress\x18\x0c \x01(\x0b\x32\x17.entities.AddressConfigH\x00\x12-\n\tfree_text\x18\r \x01(\x0b\x32\x18.entities.FreeTextConfigH\x00\x12+\n\x0bname_config\x18\x0e \x01(\x0b\x32\x14.entities.NameConfigH\x00\x42\x08\n\x06\x63onfig\"\x1b\n\rEntity_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"j\n\x0cNumberConfig\x12\x13\n\x0bhas_decimal\x18\x01 \x01(\x08\x12\x11\n\thas_range\x18\x02 \x01(\x08\x12\x10\n\x03min\x18\x03 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x04 \x01(\x02H\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"Z\n\x12\x41lphanumericConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fvalidation_type\x18\x02 \x01(\t\x12\x1a\n\x12regular_expression\x18\x03 \x01(\t\"(\n\x15MultipleOptionsConfig\x12\x0f\n\x07options\x18\x01 \x03(\t\"#\n\nDateConfig\x12\x15\n\rrelative_date\x18\x01 \x01(\x08\";\n\x11PhoneNumberConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\"C\n\nTimeConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\"\x0f\n\rAddressConfig\"\x10\n\x0e\x46reeTextConfig\"\x0c\n\nNameConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'entities_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ENTITYREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_ENTITYREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ENTITYREFERENCES_NOCODESTEPSENTRY']._options = None
  _globals['_ENTITYREFERENCES_NOCODESTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ENTITYREFERENCES']._serialized_start=62
  _globals['_ENTITYREFERENCES']._serialized_end=313
  _globals['_ENTITYREFERENCES_FLOWSTEPSENTRY']._serialized_start=213
  _globals['_ENTITYREFERENCES_FLOWSTEPSENTRY']._serialized_end=261
  _globals['_ENTITYREFERENCES_NOCODESTEPSENTRY']._serialized_start=263
  _globals['_ENTITYREFERENCES_NOCODESTEPSENTRY']._serialized_end=313
  _globals['_ENTITIES']._serialized_start=315
  _globals['_ENTITIES']._serialized_end=361
  _globals['_ENTITY']._serialized_start=364
  _globals['_ENTITY']._serialized_end=1038
  _globals['_ENTITY_CREATE']._serialized_start=1041
  _globals['_ENTITY_CREATE']._serialized_end=1586
  _globals['_ENTITY_UPDATE']._serialized_start=1589
  _globals['_ENTITY_UPDATE']._serialized_end=2134
  _globals['_ENTITY_DELETE']._serialized_start=2136
  _globals['_ENTITY_DELETE']._serialized_end=2163
  _globals['_NUMBERCONFIG']._serialized_start=2165
  _globals['_NUMBERCONFIG']._serialized_end=2271
  _globals['_ALPHANUMERICCONFIG']._serialized_start=2273
  _globals['_ALPHANUMERICCONFIG']._serialized_end=2363
  _globals['_MULTIPLEOPTIONSCONFIG']._serialized_start=2365
  _globals['_MULTIPLEOPTIONSCONFIG']._serialized_end=2405
  _globals['_DATECONFIG']._serialized_start=2407
  _globals['_DATECONFIG']._serialized_end=2442
  _globals['_PHONENUMBERCONFIG']._serialized_start=2444
  _globals['_PHONENUMBERCONFIG']._serialized_end=2503
  _globals['_TIMECONFIG']._serialized_start=2505
  _globals['_TIMECONFIG']._serialized_end=2572
  _globals['_ADDRESSCONFIG']._serialized_start=2574
  _globals['_ADDRESSCONFIG']._serialized_end=2589
  _globals['_FREETEXTCONFIG']._serialized_start=2591
  _globals['_FREETEXTCONFIG']._serialized_end=2607
  _globals['_NAMECONFIG']._serialized_start=2609
  _globals['_NAMECONFIG']._serialized_end=2621
# @@protoc_insertion_point(module_scope)
