# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variables.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fvariables.proto\x12\tvariables\x1a\x1fgoogle/protobuf/timestamp.proto\"{\n\x0cVariablesMap\x12\x39\n\tvariables\x18\x01 \x03(\x0b\x32&.variables.VariablesMap.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xa0\x0c\n\x12VariableReferences\x12?\n\tfunctions\x18\x01 \x03(\x0b\x32,.variables.VariableReferences.FunctionsEntry\x12J\n\x0f\x64\x65lay_responses\x18\x02 \x03(\x0b\x32\x31.variables.VariableReferences.DelayResponsesEntry\x12@\n\nflow_steps\x18\x03 \x03(\x0b\x32,.variables.VariableReferences.FlowStepsEntry\x12N\n\x12\x66low_no_code_steps\x18\x04 \x03(\x0b\x32\x32.variables.VariableReferences.FlowNoCodeStepsEntry\x12H\n\x0e\x66low_functions\x18\x05 \x03(\x0b\x32\x30.variables.VariableReferences.FlowFunctionsEntry\x12\x39\n\x06topics\x18\x06 \x03(\x0b\x32).variables.VariableReferences.TopicsEntry\x12\x41\n\nbehaviours\x18\x07 \x03(\x0b\x32-.variables.VariableReferences.BehavioursEntry\x12?\n\tgreetings\x18\x08 \x03(\x0b\x32,.variables.VariableReferences.GreetingsEntry\x12\x37\n\x05roles\x18\t \x03(\x0b\x32(.variables.VariableReferences.RolesEntry\x12G\n\rpersonalities\x18\n \x03(\x0b\x32\x30.variables.VariableReferences.PersonalitiesEntry\x12\x33\n\x03sms\x18\x0b \x03(\x0b\x32&.variables.VariableReferences.SmsEntry\x12J\n\x0fstart_functions\x18\x0c \x03(\x0b\x32\x31.variables.VariableReferences.StartFunctionsEntry\x12\x46\n\rend_functions\x18\r \x03(\x0b\x32/.variables.VariableReferences.EndFunctionsEntry\x1a\x30\n\x0e\x46unctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x35\n\x13\x44\x65layResponsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14\x46lowNoCodeStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x34\n\x12\x46lowFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x42\x65havioursEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eGreetingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a,\n\nRolesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x34\n\x12PersonalitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a*\n\x08SmsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x35\n\x13StartFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x33\n\x11\x45ndFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xdf\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\nreferences\x18\x07 \x01(\x0b\x32\x1d.variables.VariableReferences\"2\n\tVariables\x12%\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x13.variables.Variable\"^\n\x0fVariable_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\nreferences\x18\x03 \x01(\x0b\x32\x1d.variables.VariableReferences\"^\n\x0fVariable_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\nreferences\x18\x03 \x01(\x0b\x32\x1d.variables.VariableReferences\"\x1d\n\x0fVariable_Delete\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'variables_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VARIABLESMAP_VARIABLESENTRY']._options = None
  _globals['_VARIABLESMAP_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_FUNCTIONSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_FUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_DELAYRESPONSESENTRY']._options = None
  _globals['_VARIABLEREFERENCES_DELAYRESPONSESENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_FLOWNOCODESTEPSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_FLOWNOCODESTEPSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_FLOWFUNCTIONSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_FLOWFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_TOPICSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_BEHAVIOURSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_BEHAVIOURSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_GREETINGSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_GREETINGSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_ROLESENTRY']._options = None
  _globals['_VARIABLEREFERENCES_ROLESENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_PERSONALITIESENTRY']._options = None
  _globals['_VARIABLEREFERENCES_PERSONALITIESENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_SMSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_SMSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_STARTFUNCTIONSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_STARTFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLEREFERENCES_ENDFUNCTIONSENTRY']._options = None
  _globals['_VARIABLEREFERENCES_ENDFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLESMAP']._serialized_start=63
  _globals['_VARIABLESMAP']._serialized_end=186
  _globals['_VARIABLESMAP_VARIABLESENTRY']._serialized_start=138
  _globals['_VARIABLESMAP_VARIABLESENTRY']._serialized_end=186
  _globals['_VARIABLEREFERENCES']._serialized_start=189
  _globals['_VARIABLEREFERENCES']._serialized_end=1757
  _globals['_VARIABLEREFERENCES_FUNCTIONSENTRY']._serialized_start=1094
  _globals['_VARIABLEREFERENCES_FUNCTIONSENTRY']._serialized_end=1142
  _globals['_VARIABLEREFERENCES_DELAYRESPONSESENTRY']._serialized_start=1144
  _globals['_VARIABLEREFERENCES_DELAYRESPONSESENTRY']._serialized_end=1197
  _globals['_VARIABLEREFERENCES_FLOWSTEPSENTRY']._serialized_start=1199
  _globals['_VARIABLEREFERENCES_FLOWSTEPSENTRY']._serialized_end=1247
  _globals['_VARIABLEREFERENCES_FLOWNOCODESTEPSENTRY']._serialized_start=1249
  _globals['_VARIABLEREFERENCES_FLOWNOCODESTEPSENTRY']._serialized_end=1303
  _globals['_VARIABLEREFERENCES_FLOWFUNCTIONSENTRY']._serialized_start=1305
  _globals['_VARIABLEREFERENCES_FLOWFUNCTIONSENTRY']._serialized_end=1357
  _globals['_VARIABLEREFERENCES_TOPICSENTRY']._serialized_start=1359
  _globals['_VARIABLEREFERENCES_TOPICSENTRY']._serialized_end=1404
  _globals['_VARIABLEREFERENCES_BEHAVIOURSENTRY']._serialized_start=1406
  _globals['_VARIABLEREFERENCES_BEHAVIOURSENTRY']._serialized_end=1455
  _globals['_VARIABLEREFERENCES_GREETINGSENTRY']._serialized_start=1457
  _globals['_VARIABLEREFERENCES_GREETINGSENTRY']._serialized_end=1505
  _globals['_VARIABLEREFERENCES_ROLESENTRY']._serialized_start=1507
  _globals['_VARIABLEREFERENCES_ROLESENTRY']._serialized_end=1551
  _globals['_VARIABLEREFERENCES_PERSONALITIESENTRY']._serialized_start=1553
  _globals['_VARIABLEREFERENCES_PERSONALITIESENTRY']._serialized_end=1605
  _globals['_VARIABLEREFERENCES_SMSENTRY']._serialized_start=1607
  _globals['_VARIABLEREFERENCES_SMSENTRY']._serialized_end=1649
  _globals['_VARIABLEREFERENCES_STARTFUNCTIONSENTRY']._serialized_start=1651
  _globals['_VARIABLEREFERENCES_STARTFUNCTIONSENTRY']._serialized_end=1704
  _globals['_VARIABLEREFERENCES_ENDFUNCTIONSENTRY']._serialized_start=1706
  _globals['_VARIABLEREFERENCES_ENDFUNCTIONSENTRY']._serialized_end=1757
  _globals['_VARIABLE']._serialized_start=1760
  _globals['_VARIABLE']._serialized_end=1983
  _globals['_VARIABLES']._serialized_start=1985
  _globals['_VARIABLES']._serialized_end=2035
  _globals['_VARIABLE_CREATE']._serialized_start=2037
  _globals['_VARIABLE_CREATE']._serialized_end=2131
  _globals['_VARIABLE_UPDATE']._serialized_start=2133
  _globals['_VARIABLE_UPDATE']._serialized_end=2227
  _globals['_VARIABLE_DELETE']._serialized_start=2229
  _globals['_VARIABLE_DELETE']._serialized_end=2258
# @@protoc_insertion_point(module_scope)
