# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: translations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12translations.proto\x12\x0ctranslations\x1a\x1fgoogle/protobuf/timestamp.proto\"P\n\rLocalizedText\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x1a\n\x12is_auto_translated\x18\x03 \x01(\x08\"\x9a\x02\n\x10TranslationEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0ftranslation_key\x18\x02 \x01(\t\x12\x31\n\x0ctranslations\x18\x03 \x03(\x0b\x32\x1b.translations.LocalizedText\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"D\n\x0cTranslations\x12\x34\n\x0ctranslations\x18\x01 \x03(\x0b\x32\x1e.translations.TranslationEntry\"x\n\x0bUpdateEntry\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x11\n\x04text\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12is_auto_translated\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_textB\x15\n\x13_is_auto_translated\"x\n\x1eLanguageHubTranslations_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0ftranslation_key\x18\x02 \x01(\t\x12\x31\n\x0ctranslations\x18\x03 \x03(\x0b\x32\x1b.translations.LocalizedText\"\x8f\x01\n\x1eLanguageHubTranslations_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x0ftranslation_key\x18\x02 \x01(\tH\x00\x88\x01\x01\x12/\n\x0ctranslations\x18\x03 \x03(\x0b\x32\x19.translations.UpdateEntryB\x12\n\x10_translation_key\",\n\x1eLanguageHubTranslations_Delete\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'translations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOCALIZEDTEXT']._serialized_start=69
  _globals['_LOCALIZEDTEXT']._serialized_end=149
  _globals['_TRANSLATIONENTRY']._serialized_start=152
  _globals['_TRANSLATIONENTRY']._serialized_end=434
  _globals['_TRANSLATIONS']._serialized_start=436
  _globals['_TRANSLATIONS']._serialized_end=504
  _globals['_UPDATEENTRY']._serialized_start=506
  _globals['_UPDATEENTRY']._serialized_end=626
  _globals['_LANGUAGEHUBTRANSLATIONS_CREATE']._serialized_start=628
  _globals['_LANGUAGEHUBTRANSLATIONS_CREATE']._serialized_end=748
  _globals['_LANGUAGEHUBTRANSLATIONS_UPDATE']._serialized_start=751
  _globals['_LANGUAGEHUBTRANSLATIONS_UPDATE']._serialized_end=894
  _globals['_LANGUAGEHUBTRANSLATIONS_DELETE']._serialized_start=896
  _globals['_LANGUAGEHUBTRANSLATIONS_DELETE']._serialized_end=940
# @@protoc_insertion_point(module_scope)
