# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: handoff.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rhandoff.proto\x12\x07handoff\x1a\x1fgoogle/protobuf/timestamp.proto\"\xeb\x01\n\x11HandoffReferences\x12\x36\n\x06topics\x18\x01 \x03(\x0b\x32&.handoff.HandoffReferences.TopicsEntry\x12=\n\nflow_steps\x18\x02 \x03(\x0b\x32).handoff.HandoffReferences.FlowStepsEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xa6\x01\n\tSipConfig\x12\x31\n\x06invite\x18\x01 \x01(\x0b\x32\x1f.handoff.SipInviteHandoffConfigH\x00\x12/\n\x05refer\x18\x02 \x01(\x0b\x32\x1e.handoff.SipReferHandoffConfigH\x00\x12+\n\x03\x62ye\x18\x03 \x01(\x0b\x32\x1c.handoff.SipByeHandoffConfigH\x00\x42\x08\n\x06\x63onfig\"f\n\x16SipInviteHandoffConfig\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\x12\x19\n\x11outbound_endpoint\x18\x02 \x01(\t\x12\x1b\n\x13outbound_encryption\x18\x03 \x01(\t\"-\n\x15SipReferHandoffConfig\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\"\x15\n\x13SipByeHandoffConfig\"1\n\nSipHeaders\x12#\n\x07headers\x18\x01 \x03(\x0b\x32\x12.handoff.SipHeader\"\'\n\tSipHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"4\n\x08Handoffs\x12(\n\x08handoffs\x18\x01 \x03(\x0b\x32\x16.handoff.HandoffConfig\"\x94\x03\n\rHandoffConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12&\n\nsip_config\x18\x07 \x01(\x0b\x32\x12.handoff.SipConfig\x12(\n\x0bsip_headers\x18\x08 \x01(\x0b\x32\x13.handoff.SipHeaders\x12\x0e\n\x06\x61\x63tive\x18\t \x01(\x08\x12\x17\n\nupdated_by\x18\n \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12.\n\nreferences\x18\x0c \x01(\x0b\x32\x1a.handoff.HandoffReferences\x12\x12\n\nis_default\x18\r \x01(\x08\x42\r\n\x0b_updated_byB\r\n\x0b_updated_at\"\xd1\x01\n\x0eHandoff_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12&\n\nsip_config\x18\x04 \x01(\x0b\x32\x12.handoff.SipConfig\x12(\n\x0bsip_headers\x18\x05 \x01(\x0b\x32\x13.handoff.SipHeaders\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12.\n\nreferences\x18\x07 \x01(\x0b\x32\x1a.handoff.HandoffReferences\"\xc1\x02\n\x0eHandoff_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\nsip_config\x18\x04 \x01(\x0b\x32\x12.handoff.SipConfigH\x02\x88\x01\x01\x12-\n\x0bsip_headers\x18\x05 \x01(\x0b\x32\x13.handoff.SipHeadersH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x33\n\nreferences\x18\x07 \x01(\x0b\x32\x1a.handoff.HandoffReferencesH\x05\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_sip_configB\x0e\n\x0c_sip_headersB\t\n\x07_activeB\r\n\x0b_references\" \n\x12Handoff_SetDefault\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x0eHandoff_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"\x98\x01\n\x1bHandoff_ResetHandoffConfigs\x12+\n\nsip_config\x18\x01 \x01(\x0b\x32\x12.handoff.SipConfigH\x00\x88\x01\x01\x12-\n\x0bsip_headers\x18\x02 \x01(\x0b\x32\x13.handoff.SipHeadersH\x01\x88\x01\x01\x42\r\n\x0b_sip_configB\x0e\n\x0c_sip_headersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'handoff_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._options = None
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_HANDOFFREFERENCES']._serialized_start=60
  _globals['_HANDOFFREFERENCES']._serialized_end=295
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_start=200
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_end=245
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_start=247
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_end=295
  _globals['_SIPCONFIG']._serialized_start=298
  _globals['_SIPCONFIG']._serialized_end=464
  _globals['_SIPINVITEHANDOFFCONFIG']._serialized_start=466
  _globals['_SIPINVITEHANDOFFCONFIG']._serialized_end=568
  _globals['_SIPREFERHANDOFFCONFIG']._serialized_start=570
  _globals['_SIPREFERHANDOFFCONFIG']._serialized_end=615
  _globals['_SIPBYEHANDOFFCONFIG']._serialized_start=617
  _globals['_SIPBYEHANDOFFCONFIG']._serialized_end=638
  _globals['_SIPHEADERS']._serialized_start=640
  _globals['_SIPHEADERS']._serialized_end=689
  _globals['_SIPHEADER']._serialized_start=691
  _globals['_SIPHEADER']._serialized_end=730
  _globals['_HANDOFFS']._serialized_start=732
  _globals['_HANDOFFS']._serialized_end=784
  _globals['_HANDOFFCONFIG']._serialized_start=787
  _globals['_HANDOFFCONFIG']._serialized_end=1191
  _globals['_HANDOFF_CREATE']._serialized_start=1194
  _globals['_HANDOFF_CREATE']._serialized_end=1403
  _globals['_HANDOFF_UPDATE']._serialized_start=1406
  _globals['_HANDOFF_UPDATE']._serialized_end=1727
  _globals['_HANDOFF_SETDEFAULT']._serialized_start=1729
  _globals['_HANDOFF_SETDEFAULT']._serialized_end=1761
  _globals['_HANDOFF_DELETE']._serialized_start=1763
  _globals['_HANDOFF_DELETE']._serialized_end=1791
  _globals['_HANDOFF_RESETHANDOFFCONFIGS']._serialized_start=1794
  _globals['_HANDOFF_RESETHANDOFFCONFIGS']._serialized_end=1946
# @@protoc_insertion_point(module_scope)
