# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: integrations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12integrations.proto\x12\x0cintegrations\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc7\x01\n\x0cIntegrations\x12Y\n\x19paragon_providers_by_name\x18\x01 \x03(\x0b\x32\x36.integrations.Integrations.ParagonProvidersByNameEntry\x1a\\\n\x1bParagonProvidersByNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.integrations.ParagonProvider:\x02\x38\x01\"\xc4\x02\n\x0fParagonProvider\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61vailable_functions\x18\x02 \x03(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\r\x12\x42\n\x10\x65nv_integrations\x18\x04 \x01(\x0b\x32(.integrations.EnvironmentIntegrationRefs\x12O\n\x12integrations_by_id\x18\x05 \x03(\x0b\x32\x33.integrations.ParagonProvider.IntegrationsByIdEntry\x1aY\n\x15IntegrationsByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .integrations.ParagonIntegration:\x02\x38\x01\"P\n\x1a\x45nvironmentIntegrationRefs\x12\x0f\n\x07sandbox\x18\x01 \x01(\t\x12\x13\n\x0bpre_release\x18\x02 \x01(\t\x12\x0c\n\x04live\x18\x03 \x01(\t\"\xff\x01\n\x12ParagonIntegration\x12\x1d\n\x15paragon_connection_id\x18\x01 \x01(\t\x12\x17\n\x0fparagon_user_id\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\"\x9e\x01\n\x13Integration_Connect\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x17\n\x0fparagon_user_id\x18\x03 \x01(\t\x12\x12\n\nclient_env\x18\x05 \x01(\t\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"Y\n\x12Integration_Enable\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x12\n\nclient_env\x18\x03 \x01(\t\"Z\n\x13Integration_Disable\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x12\n\nclient_env\x18\x03 \x01(\t\"L\n\x1bIntegration_UpdateFunctions\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1b\n\x13\x61vailable_functions\x18\x02 \x03(\t\"I\n\x16Integration_Disconnect\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'integrations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._options = None
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_options = b'8\001'
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._options = None
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_options = b'8\001'
  _globals['_INTEGRATIONS']._serialized_start=100
  _globals['_INTEGRATIONS']._serialized_end=299
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_start=207
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_end=299
  _globals['_PARAGONPROVIDER']._serialized_start=302
  _globals['_PARAGONPROVIDER']._serialized_end=626
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_start=537
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_end=626
  _globals['_ENVIRONMENTINTEGRATIONREFS']._serialized_start=628
  _globals['_ENVIRONMENTINTEGRATIONREFS']._serialized_end=708
  _globals['_PARAGONINTEGRATION']._serialized_start=711
  _globals['_PARAGONINTEGRATION']._serialized_end=966
  _globals['_INTEGRATION_CONNECT']._serialized_start=969
  _globals['_INTEGRATION_CONNECT']._serialized_end=1127
  _globals['_INTEGRATION_ENABLE']._serialized_start=1129
  _globals['_INTEGRATION_ENABLE']._serialized_end=1218
  _globals['_INTEGRATION_DISABLE']._serialized_start=1220
  _globals['_INTEGRATION_DISABLE']._serialized_end=1310
  _globals['_INTEGRATION_UPDATEFUNCTIONS']._serialized_start=1312
  _globals['_INTEGRATION_UPDATEFUNCTIONS']._serialized_end=1388
  _globals['_INTEGRATION_DISCONNECT']._serialized_start=1390
  _globals['_INTEGRATION_DISCONNECT']._serialized_end=1463
# @@protoc_insertion_point(module_scope)
